from enum import IntEnum


class ETextLanguages(IntEnum):
    English = 0,
    French = 1,
    Spanish = 2,
    German = 3,
    Italian = 4,
    Dutch = 5,
    Portuguese = 6,
    TraditionalChinese = 7,
    Korean = 8,
    Russian = 9,
    Polish = 10,
    Danish = 11,
    Finnish = 12,
    Norwegian = 13,
    Swedish = 14,
    Japanese = 15,
    LatinAmericanSpanish = 16,
    BrazilianPortuguese = 17,
    Turkish = 18,
    Arabic = 19,
    SimplifiedChinese = 20



import struct
from typing import BinaryIO
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.enums.EPixelFormat import EPixelFormat


class ImageStruct:
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        self.unk_short1 = struct.unpack('<H', stream.read(2))[0]
        width = struct.unpack('<H', stream.read(2))[0]
        self.width = width & 0x3FFF
        self.width_crop = width >> 14
        height = struct.unpack('<H', stream.read(2))[0]
        self.height = height & 0x3FFF
        self.height_crop = height >> 14
        self.unk_short2 = struct.unpack('<H', stream.read(2))[0]
        self.unk_byte1 = struct.unpack('<B', stream.read(1))[0]
        self.image_format: EPixelFormat = EPixelFormat(struct.unpack('<B', stream.read(1))[0])
        self.unk_byte2 = struct.unpack('<B', stream.read(1))[0]
        self.unk_byte3 = struct.unpack('<B', stream.read(1))[0]
        self.magic = stream.read(4)
        # assert self.magic == b'\x00\xA9\xFF\x00'
        self.maybe_hash = stream.read(16)
        self.image_chunk_size = struct.unpack('<I', stream.read(4))[0]
        # TODO: Assert here?
        if version == DecimaVersion.HZDPS4:
            self.size_with_stream = struct.unpack('<I', stream.read(4))[0]
            self.size_without_stream = struct.unpack('<I', stream.read(4))[0]
            if self.size_with_stream != self.size_without_stream:
                self.size_of_stream = struct.unpack('<I', stream.read(4))[0]
                assert self.size_with_stream == self.size_without_stream + self.size_of_stream, \
                    "Stream size doesn't add up"
                self.mipmaps_in_stream = struct.unpack('<I', stream.read(4))[0]
                self.image_contents = stream.read(self.size_without_stream)
                cache_len = struct.unpack('<I', stream.read(4))[0]
                self.cache_string = stream.read(cache_len).decode('ASCII')
                self.stream_start = struct.unpack('<Q', stream.read(8))[0]
                self.stream_end = struct.unpack('<Q', stream.read(8))[0]
            else:
                stream.read(self.image_chunk_size - (self.size_without_stream + 8))  # padding
                self.image_contents = stream.read(self.size_without_stream)
        else:  # version should be HZDPC
            self.size_without_stream = struct.unpack('<I', stream.read(4))[0]
            self.size_of_stream = struct.unpack('<I', stream.read(4))[0]
            if self.size_of_stream > 0:
                self.mipmaps_in_stream = struct.unpack('<I', stream.read(4))[0]
                cache_len = struct.unpack('<I', stream.read(4))[0]
                self.cache_string = stream.read(cache_len).decode('ASCII')
                self.stream_start = struct.unpack('<Q', stream.read(8))[0]
                self.size_of_stream2 = struct.unpack('<Q', stream.read(8))[0]
                assert self.size_of_stream == self.size_of_stream2, "Stream sizes don't match"
            else:
                stream.read(self.image_chunk_size - (self.size_without_stream + 8))  # padding
            self.image_contents = stream.read(self.size_without_stream)



from typing import Dict

ps4_type_map: Dict[str, str] = {
    '863AAA0CE94B7865': "AuroraSettingsResource",
    '1FE2FA1BF49E38': "StatModificationTypeResource",
    '22114FCB99B88A': "LensFlareSparkleResource",
    '2CC51DA11B2925': "ExposureSettingsResource",
    '2FD2743C641852': "ReactOnImpactComponentResource",
    '4D2905427528B4': "SetAiStimuliModifierAction",
    '8F64FDB53491B8': "SequenceEntityResource",
    'A3B6FDE442102B': "AttachToPartMoverResource",
    'AA86FBDA101D89': "DifficultyRangeResource",
    'DB14EE070349A5': "LocationMarkerRepMapFastTravelResource",
    '1115762952DBAF7': "MerchantTradeCostMultiplier",
    '15B1905D84D2266': "HUDPopupLogicResource",
    '1B65EFA55EF18D8': "BoundingBoxBasedActivationPolicy",
    '203A0B65B2653DF': "PhysicsPositionMotorResource",
    '22841A319D0E1E9': "HUDHealthStatusLogicResource",
    '251E4B7926DFEC6': "DataSourceMerchantResource",
    '274BE4301D34C06': "DataBufferResource",
    '291CA2BFC7581A6': "PropertyIsParkouringBraced",
    '2C990B89CB43890': "SoundPadSpeakerMasterBusResource",
    '2D4F6277E730BE1': "AICargoCrabCrateComponentResource",
    '2F41C3DCD8DA475': "EffectComponentResource",
    '30D0B276F9C94B4': "CameraVisibilityCylinderResource",
    '32AE716DBE57D5D': "AILineWeaponOperationResource",
    '33420DAC13027FB': "DiscoverableAreaResource",
    '33885CF170B7D2C': "SkinnedMeshBoneBindings",
    '36679006F125B45': "BlurSettingsResource",
    '38CE3651C24FFDF': "ResistanceStatModifierResource",
    '398C8E084F67D99': "MultiSpawnpoint",
    '3A19398429EC04E': "SetFactSpawnCommand",
    '3BC176677135CC2': "XpRepresentationControllerResource",
    '3F071987468350E': "PhysicsHeightMapOffsetCollisionResource",
    '40D6E0DEF72B527': "PBDNodeStateResource",
    '41CCFB5C749FCAF': "GameViewResource",
    '45C9A253332DF79': "WeaponAccuracyResource",
    '4741AE7269C2623': "MenuEventBinding",
    '4878BA049FA7768': "RobotMeleeWeaponAnimationInfoSource",
    '4BD3CB18F9D0C33': "StaticModelResource",
    '4CB657FF65834E3': "GrainSettingsResource",
    '4E47BD665AACF55': "AIBodyComponentResource",
    '4E6D1D50B63062A': "TriggerExposedActionAction",
    '4FFA33884772515': "AIScanContextResource",
    '502786C44188D56': "AnimatedLightEventResource",
    '52DE84B2EA55ADB': "LensFlareResource",
    '53D2F23E96C0B41': "GameStatisticsEntryEnumFact",
    '573B97A23F34AFA': "MenuStyleProgressBarBlock",
    '57F7E9BC3F71B7D': "WarpedAnimation",
    '58A3A8ACE5F5DF4': "SnowInteractionSettings",
    '5D9842A96CA973E': "BooleanFactSelectEventResource",
    '619D58A19F15144': "LevelBasedXpReward",
    '65D5AF959762A59': "XpTableEntry",
    '6AE0A296C3FA208': "DestroyComponentAction",
    '6B0317ED49BB618': "CharacterUpgradeRecipe",
    '6B7436C3D07E816': "EntityGroupComponentResource",
    '6D4E8356D88EE47': "HitResponseBehaviour",
    '6DD282742FF6474': "FloatFact",
    '6E778B972E04AC9': "SuspendPlayerControlEventResource",
    '73C9F8D48BC307C': "AddHUDElementAction",
    '73D1E858416176A': "LocationMarkerState",
    '74EC162A809DB5B': "LevelSettings",
    '760EBA6AA9836A0': "PropertyIsSwimming",
    '7770B9303364364': "JumpEventResource",
    '79AD4D916A85E4F': "PropertyIsParkouringOnFoot",
    '7FEBA9CAA64A128': "MenuMovieEventResource",
    '9247AF6834B5F11': "CameraMagnetParmResource",
    '94827E7034DDFCB': "FocusOutlineSettings",
    '97DFA46ED09411B': "RandomMatrixResource",
    '98758052DC3D7E7': "DiscRocketMoverResource",
    '9B93416CB458B82': "BooleanFactConditionResource",
    '9D70B89F06FE4CA': "HumanoidDirectionalStaggerStateResource",
    'A0F79C7A5D6B5A7': "LoadingHintConditionBooleanFact",
    'A356C82FC1F66C2': "HUDDamageTypeToColorResource",
    'A3753006F84EAF6': "HitReactionComponentResource",
    'AAC27C79B4B476C': "MenuStreamingTexturesResource",
    'AF641FAFAB86C35': "LoadingHintConditionAnd",
    'AFD506B6259ECF2': "CameraMagnetComponentResource",
    'B73D91FA25AA94B': "MenuPage",
    'BCA6E8E2D9EFF53': "EquipmentModificationComponentResource",
    'BDE6BC0CF6C1D42': "EntityInstanceProperty",
    'C473EC926846C90': "HUDLogicGroupContainerResource",
    'C60729B51DED36C': "TrackDamageOverTimeComponentResource",
    'C61F7F27B95DBC1': "AtmosphereSkySettingsResource",
    'C7B616E18AA460F': "StickFunction",
    'CF6619C5DE80E4F': "BloomLookupData",
    'CFA76AA716F9308': "MappedInterior",
    'D459E5F809AA1F8': "WalletComponentResource",
    'D58F8061AA8DB9D': "AISignalType",
    'DA8EE7190FB26F7': "MeshPlacement",
    'E02735CED4F1CDF': "TextureSet",
    'F26340358E9246D': "PhysicsWaterPoolResource",
    'F58504FEA66B236': "QuestDebugInitializer",
    'F75174187BC7C7A': "EntitlementResource",
    'FDBE1131C408399': "PlayerInteractiveNotificationResource",
    'FF8F42160041322': "RocketResource",
    '1000A1FABAEBDA8E': "ForceFieldResource",
    '10284AFC8095BA8A': "ExertionAnimationEvent",
    '10434921AB3D9C5B': "MaterialLightingResource",
    '105E7C40636CBFB5': "HitReactionDisplaySettingsResource",
    '10703F68DACEEA67': "PhysicsSkeleton",
    '10D7713CF573FD50': "SoundEventResource",
    '11567B1FE84E3F04': "ImpactEffectComponentResource",
    '1161452F99D4E219': "AIHTNPlannerDaemonResourceSet",
    '11892FDDC793393C': "FocusAlertSignal",
    '119BADFD4A56C7FF': "StringProperty",
    '11C85BAA50BD0337': "HumanoidRopePullingStateResource",
    '11E82F7D9394DF95': "TestIntPropertyAction",
    '11F891A69F4D7E8F': "ImpactEffectSystemSettingsGame",
    '1207AD12ADF8E7ED': "SimpleSoundResource",
    '1247C0212B6943CA': "AttachToWorldMatrixMoverResource",
    '1250FBFC6BD354AF': "LoadingHintSystemResource",
    '128E0047198766FE': "GraphProgramStreamingStrategyResource",
    '12F3957F23DEFCA3': "MerchantComponentResource",
    '1313F40BA85C758C': "ScoringResource",
    '134A06F85743B883': "MenuRadialSectorResource",
    '1379206266B4BC63': "FastTravelSystemResource",
    '138CCBA7EB4012B6': "PhotoModeResource",
    '13B34222B4297E6B': "OutOfBoundsNavMeshArea",
    '13B5BE107D676077': "PropertyIsFalling",
    '13C7DC737B195A31': "RelativePositionLocatorResource",
    '13C80F973C99A5E2': "SkinnedMeshBoneBoundingBoxes",
    '13D29A33A5A62D43': "RobotInjuredStateComponentResource",
    '13D751AF91097309': "DisableAnimationEventsEventResource",
    '140929C275689223': "HumanoidRunningSlideStateResource",
    '145B0472256B2A68': "ObjectiveTargetArrowComponentResource",
    '14A0C9AC19095672': "MotionTableContentsGenerationResource",
    '14C350116DD3DF9C': "QuestTrackingRepresentationComponentResource",
    '150A064C5279067E': "MenuXPathAnimationResource",
    '15216F5542D69403': "FullBodyAnimationEventResource",
    '1542C84A7817E52D': "SequenceNetworkUseLocation",
    '1551C0945760E58D': "AIDiamondGroupFormationResource",
    '1590A62E65066B09': "SpotLight",
    '15C3AA3D8BB35A59': "MovieResource",
    '15E8608E4DD6F3F4': "DamageTypeResource",
    '16395198E7A2FF8D': "RobotTempBlindStateComponentResource",
    '166B3FE4EF64894D': "ImpactEffectEventResource",
    '1676425C8A17D9D2': "AISniperWeaponOperationResource",
    '168BF0880BC936E6': "SetBooleanFactAction",
    '169E4AC80EE1FED5': "HealthRegenerationParams",
    '16B2B50B9D567165': "DisableEntityCollisionEventResource",
    '16CB996715A74D3E': "AttachedLightsComponentResource",
    '16D1D4604EA5C196': "GenericPlacement",
    '16D2546D2E36BDD1': "AIMarkerLocatorResource",
    '16F0D9064893825F': "GestureEventResource",
    '16FEF2CDA82B3A9C': "LocationMarkerRepHUDAwarenessResource",
    '171C46EB47A7F3AB': "TrackingPathNode",
    '1720BD8F07AED644': "AIHTNPlannerDaemonCollectiveResource",
    '1725F7AB7E228F8C': "DataSourceCreditsResource",
    '17621276907D7EB1': "UnlockableFacePaint",
    '179744AA0EB198C8': "ExclusionArea",
    '17A177546D66FF8F': "DangerAreaSphereComponentResource",
    '17B0370E7A281416': "UseLocationResource",
    '17B553167812F8B3': "PropertyIsInBulletTime",
    '17C0B7119F2FE993': "RememberFactAction",
    '18206CEF1D24FA57': "DataSourcePlayerCharacterPerksResource",
    '18417AF9D5C52B71': "CameraModifierComponentResource",
    '1854D03758897F26': "AmmoSlotsComponentResource",
    '188B73067DAD2994': "IncapacitateWeaponAction",
    '18C4B05932464FAB': "BuddySpawnpoint",
    '1924224E93E57E1A': "SequenceNetworkEnumFactValueToNode",
    '1995F4B3A5033213': "InventoryNodeGraphPackageComponentResource",
    '19EFE33B18722F33': "SceneObjectInfo",
    '1A080D1585CD5E23': "HUDQuestObjectiveLogicResource",
    '1A51083F9FDA40A5': "HumanoidResource",
    '1A5951CD9742520F': "AmbienceSettings",
    '1A7314DFB4ECA7DB': "MedalQuestRewardDisplayEntry",
    '1AAD591A3F43BCED': "UseLocationConditionUserHasBoolProperty",
    '1ABB56D369FA6EEF': "FaceTowardsEventResource",
    '1ACB26F930AC3207': "AnimatedScreenEffectResource",
    '1AED67F539C1C3A3': "AIWeaponPreference",
    '1B005A8A773E1B9F': "AnnotationInstance",
    '1B76BFD037F3DBAC': "HUDLogicElementSliderResource",
    '1B824312C1116EC7': "SetFloatFactEventResource",
    '1B948DB34A7B6136': "FlowPuzzleSettings",
    '1BB904A51759E927': "LookAtEntitiesEventResource",
    '1BC2185A2DC95BF1': "AttachToSequenceLocatorMoverResource",
    '1BEF68E33F654121': "StaggerStateComponentResource",
    '1C3A055C2172488F': "CrowdImpostorResource",
    '1C3ECEE7F66F8797': "EntityStickerResource",
    '1C4ABBC0D390AC01': "PlacementBakePrefabCollection",
    '1C5A695D4546BA74': "ExposedEntityActionsComponentResource",
    '1C76313C0EFF4AA0': "ModelPartMeshReplacementResource",
    '1CAF6F346E931154': "LaserBeamResource",
    '1CBE4058F5BF1D48': "DepthOfFieldSettingsResource",
    '1CC182DB21D8DC1C': "MenuCatalogRobotPartResource",
    '1D485685A5F2F6EA': "AnimatedShaderEventResource",
    '1D8503DE55DF7E88': "MoveToEventResource",
    '1D9054716CCC885F': "FlickerLight",
    '1D9B803B07BDB648': "RewardComponentResource",
    '1DBB3867F2201D41': "SceneScheduleEntryResource",
    '1DBEC3DB96B688B4': "SubmixResource",
    '1DD56BB269BFC1BF': "AtmosphereBoxComponentResource",
    '1DEE132DBB5108A6': "DangerAreaCapsuleComponentResource",
    '1E233DAE0E91AADD': "SequenceNetworkBooleanFactNode",
    '1E2621C8FA90F01A': "AirNavSettingsResource",
    '1E5B9ADDE8F1FD9B': "MultiMeshActorResource",
    '1E890C65053642C5': "NavMeshBuilderSettings",
    '1E8DB469F80A6CB0': "MenuGridPanelResource",
    '1E97D9EC571D6AD7': "Climate",
    '1EB7C8D78E0A9B36': "FocusScannableBody",
    '1EE77D24A495309E': "AimDeviationResource",
    '1F20CDC12022DD1D': "CreateGrenadeTriggerComponentAction",
    '1F2C74892894E98E': "AudioPlayerComponentResource",
    '1F8238712B625EAB': "WaterEffectComponentResource",
    '1F8B6ABD0D4F3272': "WorldEncounterCollection",
    '1F99661FFCB95671': "MenuTimerResource",
    '1FD346ADF245E7E4': "EyeLookAtEventResource",
    '1FE5CA6F923FA94E': "HUDEnemyHealthBarLogicResource",
    '1FF26324CCA34EA9': "MappedFloor",
    '201E828918D8323B': "SetBoolPropertyAction",
    '204356D8721E8632': "AddItemToInventoryAction",
    '2063933A503A2FCB': "MaterialTypeResource",
    '208859AC9D03D093': "AISupportAttackTicketThresholds",
    '20A7A5E087E59B87': "DynamicSequenceEntityVariable",
    '20C6AE39C5D49878': "WeaponCookResource",
    '20CC573A77B4C921': "BeamEjectorResource",
    '20D06AAD59600257': "MultiAction",
    '20D1DACB4D7E8572': "CameraOrbitFollowResource",
    '211F58967C9DDB5E': "AmmoEjectorWeaponResource",
    '212A4E5778F4816E': "AbilitySimpleAnimationResource",
    '213CAC1964203935': "QuestRewardSet",
    '214EBE8428F8B8F2': "AnimationAction",
    '218BF163F44EB061': "AIWeaponAccuracyHintResource",
    '219D45037A96655C': "PropertyCanMove",
    '223AACCB41897578': "SimpleAnimatedLocatorResource",
    '223C6B30B340C4C6': "FactionOverrideComponentResource",
    '228294CE95A50EFF': "RenderEffectShaderOverridesResource",
    '2286D92A126111F3': "ActivityFeedResourceCollection",
    '22C8F6CBE8097AB5': "SelectResource",
    '22D21CAC871669F7': "HitResponseResource",
    '23257D0D60E7FE46': "BuyBackComponentResource",
    '23608681E8E8C9C1': "SkipSequenceEventResource",
    '23C869712CF96BE0': "CollectableTypeContainer",
    '23D86F8D5DCB3C9D': "HUDShaderResource",
    '23FEACCF4DAF508C': "ReduceIncomingAIDamageComponentResource",
    '240E0DB92F95498D': "AIWeaponPreferenceSettings",
    '24359949D42E2619': "LensFlareIrisResource",
    '24691484AAD7A2AC': "TrackingPathTrailPrefabResource",
    '248AA222815A09E9': "MenuAnimationResource",
    '250971FB56A2E037': "NodeGraphEntityPlaceHolderVariableOverride",
    '252ECBC40EBD406C': "LootSlotSettings",
    '25FD3A2821FA9665': "StealthComponentResource",
    '262F39CA748E1874': "PerkSetQuestReward",
    '26A5AE156D6A79B5': "MapZoneRevealArea",
    '270A882F55962F3D': "AIDynamicObstacleEventResource",
    '275E06DCD2F26447': "ForceSmartObjectAreaToHighLoDEventResource",
    '2788AB993F177AE9': "DismountMode",
    '27A2C3A5CE8A243E': "AIAuralStimulusResource",
    '27C568FEFD09C50C': "HUDActionPromptLogicResource",
    '27E3DA3ED61AE22C': "ParametricEqResource",
    '27E6D5044E6AAB99': "AIGroupImportanceBasedRolesDistributorResource",
    '27E9CB5FA7ABA6B4': "UserComponentResource",
    '27F7A28FCA26CCB1': "AIObserverComponentResource",
    '28522102D7329142': "SwitchInventoryEntityAction",
    '2866DF8BA41C15AC': "HUDPlayerChoiceLogicResource",
    '286E4489AEC50AAB': "AIGenericEventMessageHandlerResource",
    '28AF7E300AEBC14E': "WorldDataMapGenerator",
    '28B9804A836B4177': "LightProbeSetResource",
    '28C57FCAA542DF3A': "ThresholdBasedContextualEmotion",
    '28C99F1319E2C176': "WorldDataArea",
    '28CFF85FCE90A367': "GraphProgramResource",
    '28D37F72279BC079': "GameSettingsResource",
    '28E57DDAF05A42DB': "PushTriggerComponentResource",
    '290CC4F3642EB800': "ChargeAnimationReference",
    '29187D9044816609': "MenuTabHeaderResource",
    '292296F1E282F5AC': "VirtualRTTIAttribute",
    '292BBE12033D3857': "TextureLUT",
    '296D57D5058E0F11': "QuestLocationObjective",
    '297F2449ECFFB2F6': "PhysicsBallAndSocketConstraintResource",
    '29A7527905280363': "FloorSlopeDetectionComponentResource",
    '2A3C7DB790214B9C': "Game",
    '2A7D008CFEDA40F7': "FactCollisionTrigger",
    '2AA9A759B13A756E': "GameStatsComponentResource",
    '2ACAFE047286A508': "HumanoidMountStateResource",
    '2ADC138E1116268E': "MenuWidgetPropertyAnimationResource",
    '2B2A2C2407EB7EEF': "StaminaModifierAction",
    '2B31868F8838BD88': "CreateEntityAction",
    '2B42E5A0E3D31BC0': "MenuImageLoaderSystemResource",
    '2B87E15B0B4DD7BF': "AIVisualSensor",
    '2B9D634C4B5A2EBA': "PlacementProceduralData",
    '2C30EB580C9FE343': "BloomSettingsResource",
    '2C8D72FA1B04F0A9': "TrackingPath",
    '2CD94A577F8FB951': "MapZonePortalSide",
    '2D348E881626DA9C': "SkeletonHelpersComponentResource",
    '2D46705E44FAC189': "HumanoidSwimStateResource",
    '2D54F201A61FA5D1': "DLCVariableActorResource",
    '2D5C5B07E4CE8E34': "GameStatisticsEntryBooleanFact",
    '2D9EF04FE8009F85': "SharedPositionLocatorResource",
    '2DC078D5775B97F1': "TimerQuestTrigger",
    '2DFB6AA524DE622C': "InverseWarpMountMode",
    '2E17A9CD85FAE366': "CSoundSettings",
    '2F2E5F7E4D917DD6': "CameraActorResource",
    '2F7BAE28BB56499C': "SpeakEventResource",
    '30454D0967331462': "LocationMarkerRepCompassResource",
    '306C9A21CAC918C3': "SamplePatternResource",
    '30BF7E9A16F18DFD': "AITagToIdentifierMap",
    '30D25D5DD3A37935': "WalkAndTalkPathNode",
    '30F8029A0A88A5FD': "KnockDownStateComponentResource",
    '31003A942EED69D9': "AnimatedEntityEventResource",
    '31B368F6DDBCB2B0': "CollectableType",
    '31D65F01A3A2A761': "HUDHitReactionLogicResource",
    '321F4B133D40A266': "TextureList",
    '32352B2A3C55B24C': "GraphConditionAction",
    '325766D1175671D7': "PhysicsCollisionResource",
    '329B7CBA1843924F': "PropertyMountableIsMounted",
    '32AE1EDE38B439B2': "HUDPlayerChoiceOption",
    '32CA922B6E402BDF': "RenderDataStreamingHintDataAreaResource",
    '33843DD2B0053238': "PropertyElectricityStamina",
    '338B6F9B338DA771': "SetMoverAction",
    '3393F19806D57915': "AIFollowAnimationAimWeaponOperationResource",
    '33C93B8901E04BC6': "CreateDamageEntityAction",
    '341482797C4C4AFD': "ButtonIconCollection",
    '34164433A92D6D58': "EventDrivenStateMachineResource",
    '341E8E74D962F01E': "KnockDownStateEntryResource",
    '343E8802B8DBAF7B': "PropertyIsCrouching",
    '344F9419F90D8E41': "MorphemeEventMappingsResource",
    '346C6A49DC185594': "EnumFactDefinition",
    '347AC87ECD0A595B': "GroupSubmixRoutingResource",
    '34FAAE49A306B440': "RobotActionComponentResource",
    '353B2D32C58139BA': "ContextualTakeDownAttackResource",
    '356B8FD7711192EF': "FactValue",
    '359B8490CB4D2179': "IsTrackingObjectiveAction",
    '35E56B79353B320F': "FacialAnimationComponentResource",
    '36083A5413C37B27': "CharacterDescriptionComponentResource",
    '36105B279E1FE7FD': "PropertyIsJumping",
    '3668B1B142384D9E': "HumanoidInventoryResource",
    '36C25B51E5FD32F7': "AnnotationSegment",
    '36C8A4CE46BFD1D7': "MenuTextResource",
    '36DB0D3E3DE90EEA': "HumanoidCinematicDeathSystemResource",
    '3736B4C39D25767A': "HUDCrosshairPartSpreadAnimationSettings",
    '37423057F848ED32': "PropertyIsDiveRolling",
    '37490CC55096E177': "WorldDataPlacementMap",
    '3777A746AA40DC42': "ContextualSpeechRuleResource",
    '3788E5D177B43B32': "CharacterProgressionComponentResource",
    '385FA874928E0E17': "AccuracySettings",
    '3885AF02C86A71F0': "Typeface",
    '388B6921AC37C313': "LocationMarkerIconData",
    '38B8AD82B9C1AFA8': "DamageEntityAction",
    '38DA572DE85FCDCD': "MenuProgressBarResource",
    '39692BFCA099CC71': "AnimatedRenderZoneEventResource",
    '39C5497B896E09BE': "TerrainMaterial",
    '3A23DBA497A59C2F': "FactPauseEventResource",
    '3A34A7405832C2E9': "ScheduledSceneInstance",
    '3A3C0AF9D870A59E': "ContextualSpeechEvent",
    '3A4CFB12A048F328': "PropertyIsSlidingToUseLocation",
    '3A659CE0F9432DBD': "GameStatisticsEntryTimePlayed",
    '3A65B60391D00AE1': "AttributeFloatAnimatorResource",
    '3ABAF71D1AF524F1': "SequenceNetworkOwnerSequenceEntityVariable",
    '3ACD5D379324B6AD': "LodMeshResource",
    '3AD6009CCAE3B6E9': "MenuSpeechResource",
    '3B0122B3B40EF538': "PropertyIsInStealth",
    '3B040F1B30C2E0B8': "ShaderResource",
    '3B178A532F4FD277': "EcotopeMapping",
    '3B1CFDEAD479C5B5': "AIDynamicObstacleComponentResource",
    '3B2047B2B98BE259': "EquipmentModificationItemComponentResource",
    '3BAC118D86D5D42D': "SequenceNetworkPlayerChoiceEntry",
    '3C044275D70A124B': "AlwaysLoadedStreamingStrategyResource",
    '3C7766A599222BFC': "SequenceNetworkTransition",
    '3CFEA9018C4BB1C8': "HideInventoryItemsEventResource",
    '3D0235C5306C3E37': "SetFactEventResource",
    '3D0F781A2539E10C': "HeadLookAtEventResource",
    '3D3F929B93F5EA4E': "StackableComponentResource",
    '3D60A9A6A28A90EE': "AIMarker",
    '3D668F6CB69C6AA3': "ItemRecipe",
    '3D6A6EA3B4BBD6CB': "DestructibilityConstraint",
    '3D8070027F38A962': "InventoryAmmoEjectorResource",
    '3DB2B1C1B50D1AF9': "FollowCameraEntityResource",
    '3DB348AC55D0A13B': "NodeGraphResourceVariableOverride",
    '3DE14D1E64E1A813': "CorpseStimuliComponentResource",
    '3E27EA3FE08B5F02': "SelectResourceByAnimTag",
    '3E2F9A3E8958495B': "QueryTriggersComponentResource",
    '3E4BA0BBB05BBC7F': "FactMusicPresetCollection",
    '3E52D287531635AB': "ForgetFactAction",
    '3EB76C783C68B529': "MountMode",
    '3EE6D2C4430450DD': "EnableContextualSpeechEventResource",
    '3EEA66852C8E3960': "MaterialTypeResourceGame",
    '3F07EAF1ECC127C8': "ArmedPartDamageOnImpactComponentResource",
    '3F0A84C5F1A90C91': "PropertyIsMoving",
    '3F25B4EB24ED5EB4': "SetFloatPropertyAction",
    '3F2D5C7DFDDC7282': "ChangeInvulnerabilityEventResource",
    '3F3D405D0A0D40BF': "PhysicsMultiShapeResource",
    '3F56195C745AAEE8': "NamedDataSourceResource",
    '3FAF1CA93ABE8D9E': "DLCVoiceComponentResource",
    '3FB0D41DCB4D9C95': "DamageOnImpactComponentResource",
    '3FCEBC6413D208FD': "PhysicsRagdollResource",
    '3FDFF095F0C7AACF': "ExtraAmmoModifier",
    '3FF8669C2650EBCE': "SequenceNetworkQuestTrigger",
    '3FFA3D0DBC16EE91': "AISmellSensor",
    '3FFB0A546A8F6754': "ApplyPhysicsImpulseAction",
    '401ADA16F179A2C3': "PropertyComponentResource",
    '4035FB6EDB2ADCC2': "PlaceOnLocatorEventResource",
    '403AEDA2FF627F90': "LevelGroup",
    '4043C6A50E2DAF8B': "AIRadarSensor",
    '4056E4BAD83660F7': "DataSourceSettingsResource",
    '406294B4195F6328': "HUDFastTravelLogicResource",
    '406A285877E0DFB2': "CollectableDataCube",
    '409E5350FB4CECF7': "AttackEventResource",
    '40AAD7ACD9720C0C': "PlayerOpenMenuNotificationResource",
    '40D2331341554A93': "HUDImageResource",
    '40DA86B34D26AAEB': "GravityPocketResource",
    '40F2C51C32600B16': "MenuTemplateResource",
    '40FD1C1578DC4C19': "HumanoidSubStatePoseOverriddenByInteractiveEntityResource",
    '40FFFB73A5EB78B1': "PropertyIsZooming",
    '41DD13954B1D8F35': "PropertyIsVaulting",
    '421E9A2C8FFE3EF6': "SetStringPropertyAction",
    '423C953E75659616': "SequenceNetworkBranch",
    '428D72E128404785': "NPCScheduleComponentResource",
    '4296FF249E6F0BAD': "DispensableEntityManagerSettings",
    '42C932E14894A748': "SphereBasedActivationPolicy",
    '4346DF5BB1950013': "SoundEnvironment",
    '435B613DDED13EB2': "PropertyBasedContextualEmotion",
    '4370FBBF01D377BE': "GrenadeTriggerComponentResource",
    '43864AF5C64F01AC': "AttributeWorldTransformAnimatorResource",
    '43B6314B511706E4': "ShieldComponentResource",
    '43DCD4AB09C284B2': "AIAvoidanceComponentResource",
    '440E95D410A6EA03': "AIAuralSensor",
    '44153A852F9B775A': "WorldDataType",
    '44301399D76AD33C': "InventoryThrowableResource",
    '44700C323D0B4475': "WorldDataPacking",
    '44BC2E895361984B': "MissionCampaignResource",
    '450C9E6E67BE5802': "SetFactionAction",
    '451DBFC72F454971': "RegularSkinnedMeshResourceSkinInfo",
    '4531F29F6DC642ED': "NavMeshArea",
    '4554B3490354B78E': "ModelLodBiasEventResource",
    '45D71415E312EEA5': "AIThrowableOriginInfoMessageHandlerResource",
    '460C0C7C64593C5B': "AnnotationResource",
    '463EBB73980462A4': "WorldStateResource",
    '46416B30D31629AB': "DataSourceEquipmentInventoryResource",
    '465B97A130F8E5BD': "RenderEffectResource",
    '466B76E2221EC85E': "AIContextResourceSet",
    '472F0891A4E34F41': "WeaponAimArcResource",
    '480C69E61078A451': "HumanoidVaultTransitionCondition",
    '480D63C26C58C6D0': "DestructibilityState",
    '4857DF33ED456937': "InventoryResource",
    '48AD11C564C2501C': "EntityGraphProgramSpawnCommand",
    '48C088C93DC4BB50': "CrowdManagerResource",
    '48E57196775CC9D1': "LightBakeOnlyVisible",
    '48E5B03DAFCF332B': "GrenadeResource",
    '48E6FCAD0B746D61': "ImpulseResponseResource",
    '493539AB6EDE943D': "EquipSlotType",
    '494014BD9CD1F641': "PropertyVaultType",
    '4954769C9EC68EFD': "ProbabilityAction",
    '497E1DA3B2B9A4E2': "ChallengeManagerResource",
    '4995F333EA41CBA8': "MenuLocalizedTextBinding",
    '49A009BC97F8EE5E': "BoneLocatorResource",
    '49D8876C1BD4C98E': "RandomVectorResource",
    '49DB8ED4D1EB432C': "BoolProperty",
    '49E2635AE28F4093': "EnableMaterialLayerAction",
    '49F213D11AF248C5': "PlayScatterBlendAnimationComponentResource",
    '4A36D4284837A533': "HumanoidAIFallStateResource",
    '4A73EEBA66E662E2': "ControlledEntityResource",
    '4A796A525CB9ECC7': "PropertyIsScannedUsingFocus",
    '4A79D45D4E1AFF7F': "HumanoidJoystickWalkStateResource",
    '4AA22EA7519CC65D': "HUDLogicTimelineKey",
    '4AFAD4269F0A24A5': "Collectable",
    '4B22E97113DE1160': "HumanoidSubStateUsingInteractiveEntityResource",
    '4B2C2AA0CCC32C68': "ForceFieldEventResource",
    '4B34F08CCC651A6E': "AbilityAnimationResource",
    '4B411A82B8EDAA47': "SoundGroupSettingsResource",
    '4B963072C97B9C67': "SceneActivationCollisionTrigger",
    '4BB1E1C5229DA05D': "NodeGraphComponentResourceLegacy",
    '4BB4BCE9B52E9CC8': "FootPlacementComponentResource",
    '4BB95FAD33CEBB29': "MountVariableRange",
    '4BD7E9F7967EDA63': "PhotoModeBodyPoseLookAtSettings",
    '4BD81AB6682A9C77': "MenuLayerResource",
    '4BF789B795CB64E6': "ValueStatDisplayEntry",
    '4C014BCC50EA25F5': "ReverbPresetResource",
    '4C038D96B49D3794': "WorldDataAreaStack",
    '4C845E31A02C9891': "PostProcessEffectorResource",
    '4C848F4BA715F248': "SetTimeOfDayEventResouce",
    '4CE1B57A91DEC26A': "RocketMoverResource",
    '4CE81C155BDAE373': "StartSceneEventResource",
    '4CFC3C7AB238E95C': "CollectableStyleMapping",
    '4D1EE60CF22BB3D0': "SpawnpointGame",
    '4D2BFA8D0DD8B07A': "WorldNode",
    '4D677C2F2304814B': "MenuActionSetFocus",
    '4DCA93EDC412C9CF': "HUDVitalStatusComponentResource",
    '4DF16A9905F97F44': "XpMultiplier",
    '4DF91FD99425A2E1': "DLCLocationMarkerResource",
    '4E14A9063CCE33B4': "MenuMovieResource",
    '4E292DC9627836B9': "AnimatedPositionLocatorEventResource",
    '4E3A49471A175B8C': "FacialAnimationEventResource",
    '4E3D3F55F5AFE843': "QuestItemComponentResource",
    '4E4BB8AD90FD7658': "PropertyIsInParkourTransition",
    '4E614158948FA1CB': "AIGroupHookHtnPlannerResource",
    '4EC23BA299C51BCE': "StreamingTileLODResource",
    '4EF897CCBA267EFA': "LodDistanceOverrideComponentResource",
    '4F32F705A072C733': "WorldDataShapeNode",
    '4F75861FA82C0812': "OpenMenuAction",
    '4F949213FF811FE8': "DisableIKEventResource",
    '4FBBD90194186A97': "PhysicsLimitedHingeConstraintResource",
    '5045A409CA27C670': "SetPathHelperNodeAction",
    '50544BE8425B3371': "ReloadDurationsAnimationReference",
    '507D09F29FF07145': "CubemapZone",
    '507DD1C102D671B5': "ImpactEffectResourceCollection",
    '50C1AD6467AE809E': "StaticMeshResource",
    '5103FC99D1E1AF37': "ParticleSystemInstance",
    '512BDCB5C8D28807': "DensityWorldDataMap",
    '5177576DEF488272': "InventoryCollectionMerchantTradingItem",
    '517D35221E1A2A17': "ExecuteOnChildAction",
    '518A204BAF9BD2D1': "HUDTextResource",
    '51B9C75774F9EC2A': "AnnotatedRoute",
    '51DBA86B0A566375': "HumanoidParkourTransition",
    '5241165A20CF2A75': "CharacterTypeClass",
    '527946DBCC42AAD7': "CEffectsSettings",
    '527A7389CA083452': "RobotReplenishingStateComponentResource",
    '530B06C20C98874F': "RegularSkinnedMeshResource",
    '53198DE01BEB3E38': "DamagePassOnComponentResource",
    '53236A50A4D544F8': "PickUpControllerComponentResource",
    '53AB4BB544465342': "AnnotationComponentResource",
    '53C57490F535E605': "DieAction",
    '53C6096A9BAFACC8': "AIMoverComponentPostureSettings",
    '54140D370AE90BF1': "HUDBarLogicResource",
    '542907D494C1E03B': "EntityResourceSequenceEntityVariable",
    '5430E3F11BEBAC35': "StopSequenceEventResource",
    '544EFDD1292F0B3D': "RumbleResource",
    '545362855EB8CB5D': "PositionLocatorResource",
    '547540CF79E84EDF': "PlayerNotificationComponentResource",
    '549BAE0D8F988495': "GameLibSettings",
    '54CB70860215A9B2': "AIVisualStimulusResource",
    '54D5DCC3D873A05B': "SoundZoneResource",
    '54DB86AD22D838BA': "UseLocationConditionInventoryEmpty",
    '5563A0E91B8F80F2': "RopeAnchorEjectorResource",
    '55797A7D8C9A0A26': "WeaponAmmoChargerResource",
    '55866559C84E2E51': "DensityCurveLookup",
    '558C42495A36DF65': "AddInventoryItemAction",
    '55954E63D9B7F482': "MapProjectionSettings",
    '55E68DFC46CD7BAB': "ScriptPauseEventResource",
    '55FBB244C44B0C49': "AmmoMutatorResource",
    '5601AD0182BD8CE0': "AmmoType",
    '561E70C631931BBE': "AIHumanoidSkillContext",
    '565C2389C42F5ACA': "GroupRolesDebugResource",
    '568F8126F3CD0943': "ContextualActionResource",
    '5710E2F0EBB12F72': "HorseSequenceEntityVariable",
    '57113800667B8C94': "EquipmentStatsDisplaySystemResource",
    '572FFE2229081FD2': "QuestSection",
    '5783A47975078DCB': "SkeletonHelpers",
    '579AEB216B51814E': "PlayerNotificationPriority",
    '57A180848459C786': "CrowdSpawnManagerResource",
    '57D3293C7FACF8A4': "EntityArrayComponentResource",
    '57E956A1F89981E4': "SunLight",
    '57FE3C82020243D9': "ParticleSystemResource",
    '57FF97DE870A3A86': "PhysicsGravityPocketResource",
    '580143F3571265D2': "AIAuralStimulusComponentResource",
    '582EED89D375E4A3': "MountUseLocationsComponentResource",
    '5838B510D6ECCAE3': "HUDCrosshairSettings",
    '5854994E1E6DB174': "ZoomSetting",
    '58834E044E7D8AA2': "TileBasedStreamingStrategyResource",
    '58BF5EF60D7B8171': "AnimationTrackLinearFQuat",
    '58C4349416113F73': "EnableConstraintsAction",
    '58FAD935CADEE33D': "CollectableRobot",
    '59447BCF53008891': "StatModificationTypeCandidate",
    '5946F8AF642F75B0': "DataSourceQuestsResource",
    '5960F294AA6410A7': "MountableComponentResource",
    '59663636CBF70636': "NodeGraphEntityComponentResourceVariableOverride",
    '5977BEBFAB2B984E': "WeaponPreviewProjectileResource",
    '598538348FBD6558': "NodeGraphEffectComponentResourceVariableOverride",
    '59B3E1A852C695CE': "DispensableCategoryResource",
    '59C59F428757ABDB': "CraftingComponentResource",
    '59DB56AA6D033B21': "MenuBoolBinding",
    '59DF073CFC432910': "LoadingHintGroup",
    '59E945C542F9EA8B': "PhysicsWaterPool",
    '5A0D0023BABBE405': "MenuAnimationKeyFrame",
    '5A15FB27BEADEF2B': "HUDResource",
    '5A29707FBCCE2C1D': "PropertyLastLandingHeight",
    '5A3ECD4ADA693D7F': "SubtitlesResource",
    '5A896588287245F0': "PathMoverResource",
    '5A97F6A25E0E4C65': "ChargedValueIntCurve",
    '5A9836D86C7B209A': "WorldEncounterManagerResource",
    '5ADF990A2B0FC638': "WaterDetectionComponentResource",
    '5B2A8945F87FE9E3': "BoundingBoxVolumetricAnnotation",
    '5B5D2F4D8AB6C07A': "MenuScriptResource",
    '5B7BF56868139C11': "ReferencedSequenceEventResource",
    '5BC1E69B473AA014': "DangerAreaOrientedBoxComponentResource",
    '5BC20068B324214C': "ResetDelayedActionAction",
    '5BDC9F5E238F59EF': "MenuProgressBarBlockResource",
    '5BE0822DDD5BC9D3': "ObstacleComponentResource",
    '5BE1EA0DF830CF26': "HUDWeaponSelectionLogicResource",
    '5C348DAA983F6589': "LensFlareGlowResource",
    '5C387242B7210B33': "RobotMountedStateComponentResource",
    '5C485F13DECE352C': "HealthBucketComponentResource",
    '5C4EF3D25F4B052D': "NodeGraphBoolVariableOverride",
    '5C6C2F943195563F': "SpeedModifierComponentResource",
    '5C8AF0C07BCF569A': "ContextualWarpedAttackResource",
    '5CBC4466E0309A0A': "PhysicsMoverResource",
    '5CBD1C26E8CFBE27': "AirMoverComponentResource",
    '5CC69BF88B8CFEA3': "GameStatisticsEntryQuestCategory",
    '5CD5756431C8A131': "Ecotope",
    '5CDE2E32AC4E5B88': "MapRoadRenderSettingsResource",
    '5CF202A1F85B6A9E': "FactBasedContextualEmotion",
    '5D46B3760A01F6D6': "StaminaUsageType",
    '5D5C08775CFEADF8': "Texture",
    '5D6352C7E19BB43B': "InventoryHUDNotificationComponentResource",
    '5D8856595D7C935C': "XpTable",
    '5D8ABC5A43204A3C': "AlwaysActiveActivationPolicy",
    '5DC1E5622460EBFD': "ImageMap",
    '5DE301D1481E433C': "SubmixPresetResource",
    '5DE9F309E38D3309': "AISmellStimulusComponentResource",
    '5E501D5746BE3AF8': "QuestProgressedQuestTrigger",
    '5E6999DC6CD9A568': "RumbleEventResource",
    '5EBC76B02B4E477F': "HUDObjectNamesLogicResource",
    '5EC85D609D532BE7': "DisablePoseDeformerAction",
    '5EFD011931AAE4C1': "AIDefendAreaSet",
    '5F09C861599D11EB': "ImpactEffectResource",
    '5F0C17FA1990D055': "StaminaComponentResource",
    '5F24CCFAA9F1DAD7': "AIPathObjectCategory",
    '5F49818B56957F58': "AnimationEventActionComponentResource",
    '5F4CF0710139356E': "PlayWarpedAnimation",
    '5F6663CE2FC7D265': "RopeAmmoResource",
    '5F7C913D2E06A4B0': "ScatterBlendAnimation",
    '5FCE7EC146906528': "AICoverNodeType",
    '60083161BB886DF3': "AIHTNPlannerDaemonCoreObjectsResource",
    '606158B0DBB9FBD1': "DataSourceCollectablesResource",
    '60B3ADD988E3489B': "AmbienceSunAndMoonEventResource",
    '61131A40106D38F0': "NPCScheduleActivityResource",
    '614101C23E96EF20': "PhysicsCollapsedCollisionResource",
    '6155F8F3D7F1582C': "SlowMotionComponentResource",
    '617F8BFEB57CAF30': "EntityActionEventResource",
    '61BC2C5059DD0E44': "AIPatrolPathNode",
    '61D0F98395FFF541': "JoystickInputModifierResource",
    '61DF10A4F679474A': "VolumetricAnnotationComponentResource",
    '61FBC879FDB6AB66': "SoundMixResource",
    '62200A3EB3C5D482': "SimplePathMoverResource",
    '6233CCD75F8A0ECA': "RopeManagerComponentResource",
    '624D0C1C20DFE15D': "CameraShakeEventResource",
    '6252F4617FC94931': "HumanoidVaultStateResource",
    '62C9C195FBEE61A1': "WeaponAmmoTetherResource",
    '62D14A9D3A7F0770': "CraftingRecipeGroup",
    '6315E1A66AA4F144': "DamageStatDisplayEntry",
    '6323B42607322607': "SequenceNetworkTeleportPlayerNode",
    '6325D57E002FF2BA': "AwarenessMarkerDisplaySettings",
    '633E2764C6B231B9': "ChildEntityComponentResource",
    '6396179FCABDCF39': "AnnotatedRouteAnnotationCollection",
    '639772DAF130C8D8': "FixedPositionMoverResource",
    '63B354695F948B85': "MounterComponentGameResource",
    '63C259DFEF41C5D0': "EquipmentSlotComponentResource",
    '64091830BA6BAA21': "BuddyComponentResource",
    '646F248B7BB6BE11': "PoseDeformerResource",
    '64939CF29A9E038D': "HuntingGroundTrialLog",
    '64A86DD0634E89AE': "EntityGroupMemberResource",
    '64E7610B724CFA1A': "PickUpAnimationTypeResource",
    '64F939EBE0D29215': "IsEnemyOfInstigatorAction",
    '6540E04E065F4648': "RobotTiredStateComponentResource",
    '654C3AC4887B0B53': "UseLocationConditionUserHasBooleanFact",
    '656D54EEADBE2E74': "GStreamingSettings",
    '6574758A107629BF': "Perk",
    '65AADBF866EF33EB': "HUDVitalMessageAreaLogicResource",
    '65B2A4FDC9AEA118': "PerTileVolumeSampler",
    '65C3E53A2A530EDC': "ExtraAmmoComponentResource",
    '663BFDDB40FB9008': "AICombatSituationResource",
    '668B3C91CEA3F738': "UnlockableFocusModel",
    '66BD515879D59D5F': "HUDSubtitlesLogicResource",
    '66C05A1306C1F900': "GroundToAirTransitionComponentResource",
    '66D212783F6B923D': "MenuQuestTrigger",
    '66D6A8A67568C7E6': "SoundZoneInstance",
    '67127788D5B7EA94': "DestructibilityPartState",
    '673511A38AF875B1': "AmbienceSettingsKeyFrame",
    '6747CCF8804D7CF3': "CountdownTimer",
    '6795757209E99677': "CameraOrbitHullResource",
    '67D4A915838B87EC': "FactDatabaseGlobalContext",
    '67EDEF78A9D12E0E': "BooleanFactQuestTrigger",
    '6826CF76216B6DEF': "GameStatisticsGroupContainer",
    '6832AAA128C186BE': "SequenceNetworkWantsDismountNode",
    '68483B9E9EBD2BD5': "BuddySequenceEntityVariable",
    '684C69506B254A29': "RenderEffectSwapperResource",
    '685DC980BBF316E3': "WaveResource",
    '686542DF43A30E52': "EnumFactQuestTrigger",
    '6881F72A5FC8326B': "AIPatrolPathLookat",
    '68CAE47293B7ED70': "PerkPointQuestReward",
    '68DD2D68A6A05181': "MenuGridPanelCellResource",
    '690FF6C502B3DF52': "HumanoidZiplineStateResource",
    '69499B9076C119E0': "PropertyIsUsingHeavyWeapon",
    '69600FC0DF4C4651': "LocomotionMoverResource",
    '6965A6BB791D308B': "BoneAttachedParticleSystemResource",
    '69A855A23A35919B': "DataSourceMapIconFilterResource",
    '6A5BF44AB4E47B2A': "ContextualEmotionComponentResource",
    '6A6A09D45F407B33': "LocationMarkerRepHUDResource",
    '6A6ACFFC86FC7F31': "HUDNotificationType",
    '6A9A16EC28D42406': "EntityImpostorResource",
    '6AC301E4E924DE70': "SmartObjectArea",
    '6B1644EF58E69ED9': "AmbienceManager",
    '6B6210AE84579AEE': "OverrideAirSceneRestrictionComponentResource",
    '6B77AF8FC3DB1052': "AnimationTrackLinearFVector3",
    '6B9DD34BD83ADB76': "LootData",
    '6BB025C4A1A03CE8': "EntitlementComponentResource",
    '6BD5A4CDDEBFC757': "AwarenessStateDisplaySettingsResource",
    '6BDCF662A3A5FB55': "SceneResource",
    '6BDDDE268BE70D0E': "QuestResource",
    '6BDF8CD707A3275A': "DensityAdd",
    '6BEAB563291FF330': "ForceFieldManagerSettings",
    '6C0CC5CB0F8F3EDF': "RegionalAction",
    '6C242F6D4D4621BA': "MenuArrayBinding",
    '6C6F25D2EE5C4B04': "ItemQuestReward",
    '6C6FD034C9B9E5D5': "OmniLight",
    '6C925304E78CDC46': "RemoveActorEventResource",
    '6C93B424CACD581A': "GameStatsTrackingComponentResource",
    '6CB0B5195FB563A1': "WorldDataEcotopeIndexMapEntry",
    '6CF86E12E2DD1199': "HumanoidSlideStateResource",
    '6D3D6070FA5620DE': "WeaponBowStringResource",
    '6D404AF0B8437F42': "LensFlareGlintResource",
    '6D7A67ACC44D308A': "DensityCompare",
    '6DB20E2303807228': "LoadingHint",
    '6E141D4E3F12C88A': "DynamicSpawnManagerResource",
    '6E1D227629C4B406': "AuroraStaticSettings",
    '6E56C60BC8B94D5A': "MenuPanelResource",
    '6EBF5E50F281FC7E': "FocusCollisionTrigger",
    '6F10343B959E2947': "DamageCausedReportComponentResource",
    '6F4124C1FA225B6E': "PatrolSpawnCommand",
    '6F7801D6B142A131': "HUDDamageNumbersMergeSettingsResource",
    '6F9216828ACE98A7': "DensityGraphProgram",
    '6F92EEFC01469644': "ContextualActionComponentResource",
    '6FAE1D17F9AE165C': "AIScanMotionResource",
    '6FB5B5B09684CEB9': "MenuActionScriptFunction",
    '6FC26E8595F5D09A': "HealthbucketConsumableComponentResource",
    '6FDA539BFDFB1D56': "InventoryEntityResource",
    '6FEEB5337B0DD45B': "AIIndividualResource",
    '7045483040115610': "PropertyIsAiming",
    '70540C4A1D6A2F97': "LevelData",
    '706C561E5C2A9E0C': "NodeGraphCurveResourceVariableOverride",
    '70984C2CF4D62844': "PhysicsHingeConstraintResource",
    '70A5CDDBA2A648EF': "AIGroupRoleDescriptorResource",
    '70CA02AB7F95D3F1': "SimpleAnimatedEntityEventResource",
    '70DA20762EC279DB': "OverrideEyeColorEventResource",
    '70E5B7F389530D87': "AIStaticCoverMapSettings",
    '70F4B4C2F50559A3': "SharedPositionVariable",
    '71156D53995488B7': "OrbitCameraActorResource",
    '714B150A19EFC2A9': "HarvesterComponentResource",
    '71C254683E13FE36': "EntityPlaceHolderSequenceEntityVariable",
    '727C6B8E8A93BB50': "WorldMapZone",
    '72B62F492658C554': "ScaleEntityFromAnimationComponentResource",
    '72F1332BB459B417': "WeatherSystem",
    '7359066B18A65205': "WorldDataBakeSettings",
    '736AFE97D3999282': "StaticMeshSimulationInfo",
    '737E84C3973EDB73': "WorldDataTextureMap",
    '738DBDFF5BC418A4': "TrophySystemResource",
    '739AB497DD04F1B5': "PlacementSet",
    '73B1F3C970062210': "CrosshairColor",
    '73C816080D560127': "DataSourceFactsResource",
    '73D1B9AEB95ADE73': "SavePoint",
    '73D6D5DEC1294B2C': "CreditsColumn",
    '73EAA802EDDE2C60': "GameStatisticsEntryOneOfItems",
    '73EF36F6B5E253D7': "HUDTimerSettings",
    '740369B64007CE80': "UpgradableStackableComponentResource",
    '741C6EA0E5BC3F4B': "StatsDisplayResource",
    '74D4997FC49137B3': "FlyoverDeathCameraEntityResource",
    '74E962685ECE49BC': "AIProbabilityDataSetResource",
    '74FC569156147470': "PropertyIsSliding",
    '7570D3844A7B7D3D': "RenderZone",
    '7624B28D962C4F05': "ObtainItemsQuestTrigger",
    '7675985B0BCC0A8E': "LookIKComponentResource",
    '768CC4FD58A828B6': "RTTIObjectTweakValue",
    '7697DE19A7295FF9': "ExtraArmorComponentResource",
    '76A830E8FD6327DD': "SetFacialEmotionEventResource",
    '76C45BC783701DD1': "MovieListResource",
    '77086500A70C3E1B': "AIMovementAttackResource",
    '7756728B0905BD7B': "HitReactionPartResource",
    '77CBAE4136D6E19C': "LocalizedSoundPreset",
    '77E3BD30F118BEDA': "AIPerchMarker",
    '78026BEDFDB14FAE': "UseLocationConditionSet",
    '780EDD9B4E832B98': "PickUpReactivationType",
    '784C39DB2503AD65': "InventoryLootPackageComponentResource",
    '7858094AF3C4E895': "MounterComponentResource",
    '78A2ECB8FF63BDFB': "NavMeshAreaTag",
    '78AD26FD3F3BDC8A': "MeleeDamageComponentResource",
    '78B2BFED07F2636A': "MapIconFilter",
    '78C2D25A923D336D': "EntityResource",
    '791ECB779DD33586': "AnnotationPoint",
    '7936998FEE96244A': "DiscoverableArea",
    '79470794DE1E91AF': "PlacementTile",
    '794936A0834AAA6D': "WeaponSwitchEventResource",
    '794E767E98ADBB40': "WeatherSetup",
    '79B44FB79B8E3722': "DifficultyManagerResource",
    '79C5D0DC8E1983C0': "PropertyIsSprinting",
    '79F828ADF03202CC': "ImpactEffectAction",
    '7A3765A14CD99EA4': "QuestSystemResource",
    '7A73D327B1E7ADD6': "HitReactionSeverityModifier",
    '7B08FA713569E932': "DamageStatModifierResource",
    '7B5CD205DABEC57A': "InterruptEventResource",
    '7B89DD5C0B129C0A': "FocusScannedInfo",
    '7B91DB9D9BB085BF': "HumanoidStaggerStateResource",
    '7B98B766BD2876DC': "LookAtEventResource",
    '7BAACA604E63F4E2': "DataSourceEntitlementsResource",
    '7BAFC581BF3D10C1': "InventoryNothingResource",
    '7BCD7EE0AA9A0D62': "FootstepAuralStimulusResource",
    '7BF618EFFCA0173D': "AISpringArmOperationSettings",
    '7BF86215E86CC5B1': "MenuActionQuitMenu",
    '7C05DC64171E9B69': "AIGroupResource",
    '7C3B8107CB0FA935': "VertexArrayResource",
    '7CB9157A72A4C880': "SlowMotionSettingResource",
    '7CD9AF983C5B087D': "GameStatisticsGroup",
    '7CF5995AA39F60FA': "EmptyPickUpAnimationTypeResource",
    '7D12DA6AB8EE6320': "HealthRegenerationDurationParams",
    '7D1B4D66CD47D9C1': "SpawnSetupSequenceEntityVariable",
    '7D3AE170B2CE4B79': "WalkAndTalkPathEventResource",
    '7DB65B81636FA670': "PlayerLookAtPointLocatorResource",
    '7DDE4D639B8CAB25': "RobotMeleeWeaponExitState",
    '7E05F1859F9877E4': "PhysicsCollisionInstance",
    '7E14A43924AE8355': "ShaderFromFileResource",
    '7E7E4997B8ACAE8A': "DelayedAction",
    '7EAD4DC913259B73': "InventoryItemComponentResource",
    '7ECD019C0F56E1CE': "AIHTNPlannerDaemonFriendliesGameResource",
    '7F0B5299A2CCEF66': "MenuActionBackToPage",
    '7F7D0B90AF283F82': "RadarDomeComponentResource",
    '7FB31DA03A3DB4C9': "EnablePartsAction",
    '7FCBFC0EB0707995': "LookSpeedSettings",
    '7FCFD4622A2FFB9C': "PropertyBoxAtmosphereFactor",
    '7FD22C39A7724712': "QuestCategory",
    '80170626120D2589': "GenericInstance",
    '80764FDEFE565019': "PlayerToolComponentResource",
    '80B7B5154FE94F8A': "ThirdPersonPlayerCameraComponentResource",
    '80D7DDEAE673645E': "AmmoSlotResource",
    '80DB30002C895BE5': "Spawnpoint",
    '80F08C941E50D0B8': "PlayerRepellingComponentResource",
    '815DE4AC7BA4815C': "CameraZoomProperties",
    '815E9E86726F9522': "SetShaderVariableAction",
    '8207E038821AAEDF': "NodeGraphComponentResource",
    '8285D93A649A8ADA': "CollisionQuestTrigger",
    '82A3887CE83918A2': "MenuShaderPropertyAnimationResource",
    '82B4805259790FAE': "PropertyIsUsingFocusMode",
    '8329472C15B92F74': "LoadingHintConditionEntitlement",
    '833B531A77302828': "SoundMixStateResource",
    '8363DE3F10CA3486': "TagProperty",
    '83662DF6260C8DE2': "AIColumnMemberFormationResource",
    '83AADF670FAE7536': "GlobalRenderVariableInfoSet",
    '83C802AE207FAC4B': "SkeletonAnimationResource",
    '846E0A48ADD1E3E8': "HUDCountdownTimerLogicResource",
    '848F06107A40C2EF': "AIContextualSpeechEventMap",
    '8491C63E4EE267D6': "ThrowableMoverResource",
    '84E0245DB68BA802': "HUDLogLogicResource",
    '8556B850ED35363A': "RobotMeleeWeaponDamageEvent",
    '857DAE34C091FEC4': "PBDBodyResource",
    '8593025EEA4C957B': "UseLocationResourceGame",
    '85C7D522A84828E8': "DataSourceResourceInventoryResource",
    '8607CF8018ED0A24': "MenuDataResource",
    '867A26B5D5C92319': "OverrideCameraDoFEventResource",
    '86B5295F117FB660': "SpottableComponentResource",
    '86B64BB939ED7E15': "QuestGenerationSettings",
    '86D45CAE02A4A643': "AnimatedLocatorResource",
    '8722385043D53B1C': "AIHTNPlannerDaemonCombatHistoryResource",
    '8737C387AC9D5771': "InventoryCollectionEquippableAmmoItem",
    '873D69111E6F7262': "MusicResource",
    '8746F99529328C00': "DamageTypeStatsDisplayResource",
    '87517769AFC48527': "DelayedDeathComponentResource",
    '8766C0302CDFA0D0': "AttributeAnimatorComponentResource",
    '879537E1B2CFFE28': "SetIntPropertyAction",
    '87CA93879404520F': "InGameMenuResource",
    '88346EC71F50AE25': "InventoryCollection",
    '8856BBF4EDBADB97': "SetFocusEventResource",
    '88578FDA8DA887D7': "ContextualSpeechComponentResource",
    '88615D2EA3141DD0': "AutonomousBehaviorEventResource",
    '88830A1231924841': "DestructibilityHitReaction",
    '88898E308BEDD840': "CreateDangerAreaAction",
    '88A9183EB45040C0': "AIIndividualHookHtnPlannerResource",
    '88AD2FC71580BE72': "PostureEventResource",
    '88C1DCFA71106733': "SequenceNetworkNodeGraphNode",
    '892F42836F56D0CD': "InventoryCollectionEquippableItem",
    '89551C503BF6ABB3': "AISpreadWeaponOperationResource",
    '896E7EACFC4B7D96': "FactDatabaseResource",
    '8984B2BEDA77C1E2': "PhysicsWaterPoolFromHeightMapResource",
    '899820101DFC8502': "ActivityMedalQuestReward",
    '8A1EF4B2B14E6BE3': "ImpactMaterialTypeRemapComponentResource",
    '8A2115A503663678': "HideActorEventResource",
    '8A48A808702D0C75': "InventoryCollectionMerchantTradingItemTradeListItem",
    '8A4D31ADB461F239': "WeatherAmbienceCycle",
    '8A821757234F9EB8': "RobotMountedWeaponComponentResource",
    '8A92DE79CF1F29B3': "AISkillManagerResource",
    '8A96EA1F7817B3F5': "DefendSpawnCommand",
    '8AA34AA6B1B0BC2D': "GameInputJoystickResource",
    '8AB655EC11E0AC76': "WorldEncounter",
    '8ACA75C3B1509B4E': "SusceptibleToDamageComponentResource",
    '8AE3198D6A024FDE': "DismountAction",
    '8AE81F307899630C': "ContextualSpeechEventMappingResource",
    '8B602E45F1E03143': "BloodPuddleSettings",
    '8BDD8244FF1B6899': "EntityUsedQuestTrigger",
    '8C3B28FD23B8F6C9': "HideHUDEventResource",
    '8C400B44F1B90B56': "LayeredIrradianceDataForTile",
    '8CA36C539F8A3DAE': "PlacementLayerGroup",
    '8CA9B344177F16BA': "ScavengeHelperComponentResource",
    '8D0BEAF67241A825': "AISmellStimulusResource",
    '8D195DD329FF7055': "PerkSet",
    '8D40575C25B16925': "AIAtmosphereBox",
    '8D41A2831E1730D2': "PathResource",
    '8D5A13C6B1CD1C2E': "SkinnedModelResource",
    '8D689EB697F00BEE': "NodeGraphAttachedLightsComponentResourceVariableOverride",
    '8D84D246662B56D4': "GameStatsDamageEntry",
    '8D996A643E5DB186': "PropertyGrassHeight",
    '8DD7CDD707C905C0': "ScreenEffectEventResource",
    '8DFB356D90E94547': "PrefabInstance",
    '8E110D2854135813': "NodeGraphIntVariableOverride",
    '8E14FC1C297C1A17': "ChargedValueCurve",
    '8E485171B26AEF87': "SceneScheduleResource",
    '8E486D541A9F40E1': "ForceFieldInstance",
    '8E7535EFE3E51D18': "VegetationCollisionComponentResource",
    '8E897AA8B1F6FC19': "PhysicsShapeResource",
    '8E9A0949EA847991': "LightEventResource",
    '8EA288ABF194DBD2': "ModelPartResource",
    '8EAB7F1CC8DFCFFF': "SwitchStateAction",
    '8EAE8F56D7DA3B86': "LightShaftSettingsResource",
    '8ED1E0FF56B0B20F': "OmniLightResource",
    '8ED73752F16A9B8A': "AimerWeaponResource",
    '8EE8B64CC2B58D30': "Level",
    '8F687D76221B1C72': "WeaponMarkerMapping",
    '8F79FDB609389E3C': "MeleeDamageDirectionalShapeCurve",
    '8F8A6C686424689E': "QuestTrackingQuestTrigger",
    '8FD09D0B35E909D4': "ControllerConfigResource",
    '8FE07830BBFD7FA4': "MagazineResource",
    '900765226EF3BAEC': "HUDPlayerChoiceOptionState",
    '9052D217C2207A59': "AttachToHelperPositionMoverResource",
    '9074915484E46E4E': "AIBodyPartResourceSet",
    '907FE59301ABC93A': "TestBoolPropertyAction",
    '9094E282C7DA3267': "SequenceResource",
    '909C1EE966539B74': "UseLocationComponentResource",
    '90C97CE9854A7E59': "ExecuteNodeGraphAction",
    '90F285C5EE01620E': "NodeGraphFRGBAColorVariableOverride",
    '910E0851ABBC4785': "SoundMasterParametersResource",
    '912F71027C5E9CB7': "CrowdZone",
    '91313635D2D5F84B': "LocationMarkerBreadcrumbingSettings",
    '915E8392DE2FC4CD': "AICorpseFoundMessageResource",
    '917E9D02821A7832': "HUDBulletTimeIndicatorLogicResource",
    '91A79974501E3254': "MappedExterior",
    '91B3373162191C0E': "InventoryControllerResource",
    '91F611CBBC3FED32': "MusicFactValue",
    '920580544F5B9C89': "TalkPriority",
    '921397E07300755A': "AreaBasedStreamingStrategyResourceGame",
    '92204D02A5F24FB1': "NodeGraphDamageSettingsVariableOverride",
    '9240A00930BAA2F1': "AIDefendArea",
    '92D761B55BE2BF8B': "AreaRestrictionSpawnCommand",
    '933F4BD2AB48A4BA': "HealthHUDNotificationComponentResource",
    '9348DF23DA578711': "CameraVisibilityComponentResource",
    '9362D903F7D4D6F0': "GameStatisticsEntryIntegerFactValue",
    '93632BD2DE8F4099': "FlyoverCameraEntityResource",
    '9375927C7420C7B1': "HeadGestureEventResource",
    '93C7D673C0BD7D5D': "GameStatisticsCategory",
    '93FD2405628C82FE': "AttachedDamageParticlesComponentResource",
    '941B53E40EBA740F': "QuestEntityObjective",
    '945D109E1FBA43B6': "VoiceResource",
    '9464FE6E52276094': "LaserTriggerComponentResource",
    '950DACB8D39F183E': "AISignalResource",
    '950E14D6672AE91C': "RobotMountedWeaponInputMappingResource",
    '953AB78EC16EA196': "PropertyIsPerformingTakeDown",
    '9564FAF31AEA1EAC': "FocusScannableCategory",
    '957CFE66184EE208': "FocusLocatorResource",
    '95B662CEDC487B87': "EntityActorResource",
    '95B798AC42B4E45C': "AIEventMessageResource",
    '95F3A07434ABEAE0': "ScreenEffectResource",
    '96219C9336E3988C': "SonicStunComponentResource",
    '962A66A74541B42C': "DecalResource",
    '96A3DFCE8C6D736B': "TetheredAmmoPileComponentResource",
    '96D804B315D4BF33': "WorldEncounterCategory",
    '972C0CDFBE90F955': "NodeGraphFloatFactVariableOverride",
    '97336D70DD4AFFBC': "EmbeddedFileResource",
    '9741A08CE6C7F566': "IndirectLightingBakeZone",
    '97422E97C7A661D2': "StatModificationResource",
    '97EF6AD9E7284B50': "PostProcessSettingsResource",
    '97FFC11EDDA3F591': "PropertyInCombat",
    '9817BFA8FD400E68': "PatchedSpeakEventResource",
    '9821D63AB7F998C1': "FacialEmotionAnimationResource",
    '982E7E2EA82AAFA8': "SequenceNetworkPlayerComponentResource",
    '985D2CD65C07569F': "MorphemeAnimationResource",
    '9883422684D9698D': "PropertyIsInParkourReaching",
    '993D278B65361B3F': "CreditsRow",
    '994D33C4AAB96225': "ReloadDurationSettings",
    '9961DC4C6235F4F6': "IsPartDeadAction",
    '9973062783B9D66A': "SpotLightResource",
    '9977B2D93018036E': "ThirdPersonCameraFOV",
    '997D4203B766DA52': "ShaderFloatAnimatorResource",
    '999D64F52DC440C3': "SoundMasterBusResource",
    '99A6ADD1BD056154': "EnumFact",
    '99C900E696796015': "HumanoidMoverResource",
    '9A8E521F45991CCA': "CameraMagnetManagerResource",
    '9AC42A1DD72D537A': "HealEntityAction",
    '9AED97E87FCAE2FE': "LocationMarkerResource",
    '9B238F49D144FE4E': "DensityConstant",
    '9B3DAB8E924881D1': "InventoryCapacityComponentResource",
    '9B8344CB4E769414': "ContextualActionVictimComponentResource",
    '9BE462083026FD67': "LensFlareStreakResource",
    '9BE4EBB1350F1BF8': "AmbienceFloatAttributeTrack",
    '9C495FE1CA4D4894': "LayeredIrradianceDataForRegion",
    '9C4ACEDD57B7F78E': "GameStatisticsEntryCollectableContainer",
    '9C78E9FDC6042A60': "UITexture",
    '9C8D10CB69B2CFF5': "AIGroupCombatCoordinationRolesDistributorResource",
    '9CB9B02442258EFD': "MorphemeNetworkDefResource",
    '9CC409385C3BA075': "MenuTextureBinding",
    '9DC53624DFEB4840': "DensityFilter",
    '9DCE0075718F99AF': "MenuRadialWheelResource",
    '9E3121EE87D71446': "PlayerSequenceEntityVariable",
    '9E56AAF9E485ACEE': "ConditionalLookAtEventResource",
    '9E5FC0A6E8D8704A': "CollectableVantage",
    '9E8DCB60203290EA': "SequenceNetworkInterruptHandler",
    '9EA3404334F8505F': "OverrideAutoContextResource",
    '9F1583D8A5ABF02A': "CareerUnlockSystemResource",
    '9F6A9CFF72BAB426': "PropertyFloorMaterial",
    '9F7C6A1C78AF4DB7': "HumanoidBodyVariantGroup",
    '9F9DD57893E3818E': "AttachPhysicsRagdollToHelperMoverResource",
    '9FF285658BAD75F0': "HairSimMaterialList",
    'A03C0DF215502A71': "EntityComponentSetResource",
    'A0A2A87DE45E3502': "CreateEntityActorResource",
    'A0ACFA640D93E82B': "MenuSelectViewResource",
    'A0BCB6A7B8180FAD': "HealthRegenerationComponentResource",
    'A0CEA726B9DF97B7': "ItemPriceInfo",
    'A0E75E20ECE8AE36': "HumanoidKnockDownStateResource",
    'A0FC34207F3BF3DC': "ActivityMedal",
    'A15BF43D1BDBD5ED': "IgnoreCollisionWithEntitiesComponentResource",
    'A19538A907880072': "TrophyResource",
    'A197F6B7E90AAC21': "SequenceNetworkEnumFactNode",
    'A19AA6E50BD842C7': "LootSlot",
    'A1E5DCA2F792B93E': "HUDCompassMarkerLogicResource",
    'A20BB76FF21C2808': "MenuTabpaneResource",
    'A210E74789749A9F': "SpawnAppearancePosition",
    'A2950759F9745945': "GCoreSettings",
    'A29CD0A813391689': "CustomInstigatorComponentResource",
    'A2A0261C73FA6FDA': "AmbienceBiasSettingsTrack",
    'A2AB0D16DE1CFE77': "SimpleParticleSystemResource",
    'A36B54C9460CFD51': "AmbienceColorizeTrack",
    'A3BB05B435E7D4B0': "StartAudiologNotificationResource",
    'A47C5904436F50F3': "StencilBufferComponentResource",
    'A48C750704CB82AC': "NPCScheduleResource",
    'A4D8032F55B04C40': "CombatHonorsManagerResource",
    'A4E899CB6A14AA76': "EnvironmentSound",
    'A51AEE13FF59C0F1': "WeatherLimitsEventResource",
    'A523887E53346FA4': "StaminaModifier",
    'A5283947471E4C9E': "GraphConditionResource",
    'A59E6D5D4C6DE17A': "CollectableRegion",
    'A5B38AE190F649E2': "CollisionTrigger",
    'A5D856AEEC225E8A': "FloatProperty",
    'A5FD01E7CE142980': "AimingMagnetComponentResource",
    'A617B06C0F166693': "DamageAreaResource",
    'A689B798C425CB52': "VoiceComponentResource",
    'A690CC0B8AFCCEFD': "KillPartsAction",
    'A6ADB6E7A5B4D298': "EntitySpottedQuestTrigger",
    'A6FC41E982818491': "FocusTargetComponentResource",
    'A71A1D3CBB1DC912': "MapResource",
    'A73A42EC17B1FC41': "LightProbeHintSurface",
    'A78C863FAF7791B1': "BokehSettingsResource",
    'A7A3F8ECBD70E197': "ForceFieldSpringSettings",
    'A7B144A16B6AA9D5': "PlayerCardResource",
    'A8C33EC2AA776232': "AIJumpLink",
    'A8E4C0C15B0FB8FF': "SetVolumeEventResource",
    'A91E4E06B14D7B0D': "BoundingSphereVolumetricAnnotation",
    'A92B2C6040AAE55D': "DLCReviewSaveResource",
    'A9391772857671AB': "ShaderAnimationAction",
    'A94A831CA5252531': "IndexArrayResource",
    'A9558A0386EA2885': "SoundSystemSettings",
    'A9682A71BDF9848D': "SelectResourceByEnumFact",
    'A97082C73B2BC4BB': "ObjectCollection",
    'A97CFBF2788C8450': "MenuStyleClass",
    'A97F2B6EF0A3A475': "AICorpseMessageHandlerResource",
    'A9B2A0734E7EE12C': "EntityProjectileAmmoResource",
    'A9DA4CE3A3485846': "SoundMixStateEventResource",
    'AAB194EE53B3DD7A': "WeaponChargeResource",
    'AAD4389E5E93BE45': "CameraModifierResource",
    'AAE61CFF1DD1A1DF': "BulletTracerSettings",
    'AB06882C38F96965': "LeadingMagnetComponentResource",
    'AB22C29E4E06E8D3': "VoiceSignalsResource",
    'AB2761AF63663C6C': "PhysicsFixedConstraintResource",
    'AB34641EA545AAD3': "PrefabResource",
    'AB3AD669D1DE31CC': "DataSourceOutfitInventoryResource",
    'AB8C48D97E044FB6': "SelectResourceByBool",
    'AB9442134F0B5AB9': "DataSourceGameStatisticsResource",
    'ABD69A7A43EEF520': "HitReactionSeverityProperty",
    'ABF15720D9BA74AF': "CharacterUpgrade",
    'AC53499DCF12479D': "PropertyIsInGrass",
    'AC5B0871BF704897': "HUDFocusLogicResource",
    'AC5C5F307EF02A00': "MarkerRepState",
    'AC798645815DEE32': "CreateExplosionAction",
    'AC805A0FA4D88E60': "AbilityPoseDeformerResource",
    'AC9E3DD547F3DBA2': "AIScanExpressionParams",
    'ACB2E430A71FC0C3': "ZiplineDetectionComponentResource",
    'ACE2BE5671EF6723': "AmbienceCycle",
    'ACFA423195395E74': "HUDElementResource",
    'AD0D052D5D73460E': "CameraEntityResource",
    'AD403ADC2C79BAF2': "HUDLogicElementExpanderResource",
    'AD4F5E4B6EA80D88': "NodeGraphVec3VariableOverride",
    'AD6946A34C7E9DE0': "PickUpAnimationComponentResource",
    'AD6D1F9435F1B423': "UIEffectResource",
    'AD88356F1CE06A1E': "ParkourComponentResource",
    'ADB946D8B2E76997': "HUDObjectIconsLogicResource",
    'AE0FA244CA3EC77F': "MotionTableResource",
    'AE2E27FF10193A40': "RobotMeleeWeaponAttackState",
    'AE3879ADCABFEC30': "ColorizeSettingsResource",
    'AE5450BB1F13BCE0': "SetEnumFactAction",
    'AE65B0664A79919C': "AmbienceLightingSettingsResource",
    'AE6BB1354F364476': "AISubmergedAuralSensor",
    'AE7512503D02ADE5': "BulletEjectorResource",
    'AEAE9125075AEE8B': "LoadingHintConditionCauseOfDeath",
    'AEBE8FDA527B5635': "SequenceResourceBase",
    'AEC97CD5FF5830DF': "PathHelperNodeComponentResource",
    'AEEA23E8B097756D': "ScreenSpaceQueryResource",
    'AF02AC68BC63DD71': "HumanoidAirControlComponentResource",
    'AF2839005FE128A3': "ExplosionResource",
    'AF42001FBEDCEE42': "StopSceneEventResource",
    'AF45667E060C2F56': "HUDLogicGroupResource",
    'AF82B6113402BEE7': "ObjectAttributeAnimatorSetResource",
    'AFB216CC6CF53DAC': "DiscoverableAreaPlayerComponentResource",
    'AFB748A0ADAAFE41': "AIExpressorComponentResource",
    'B01FD2C28A7AD9AD': "PlayerLookAtTargetEventResource",
    'B073BB0078B51B24': "PropertyIsCurrentlyIdentifiedByHumanoid",
    'B0A61DDA9BFDE4E5': "RandomAction",
    'B10ACCC0C628651B': "HumanoidFallStateResource",
    'B1128DFAA3CFA4B0': "GlobalDamageModifier",
    'B13ECB06B9F256D0': "PlacementBakeData",
    'B1513E0E54460428': "GameEventManagerResource",
    'B1841D9354ABE76B': "HUDDamageNumbersLogicResource",
    'B1A5F879197F364D': "PickUpItemAction",
    'B1C3062F5F5C6F99': "NodeGraphModelPartResourceVariableOverride",
    'B1DFFF577EBCB1A7': "ConvolutionReverbSubmixResource",
    'B2162FB1B367D482': "HumanoidParkourStateResource",
    'B250325EADBFB212': "UseLocationConditionUserHasEnumFact",
    'B268303462054031': "RewardManagerResource",
    'B2E62560941820EC': "StartAndStopSceneEventResource",
    'B30EB14177502798': "CharacterUpgradeSet",
    'B34064332C1EE620': "VantageComponentResource",
    'B341820941F959C3': "PostureSettings",
    'B38CB7BC179CF40F': "DensitySetRange",
    'B392F2AA62D6539F': "PlayerActorResource",
    'B3C9DC719450B961': "GSequenceSettings",
    'B40D5D07E49C3282': "BooleanFact",
    'B43B1C00214E16DF': "SoundListenerOverrideEventResource",
    'B476D16950ECFE62': "MenuLocalizerResource",
    'B5034A71A2803089': "WeatherInfluenceFactor",
    'B52CAB4C2A7CA040': "MortallyWoundedComponentResource",
    'B53BA2C0033A8EA1': "EjectLocationResource",
    'B56E7147F8D2976A': "PickUpComponentResource",
    'B56F56ECB18E26EE': "AIManagerResourceGame",
    'B57725E85A124BC7': "EnumFactValue",
    'B57FDC03AEE67814': "MultiMeshAnimationEventResource",
    'B598E2629C748C18': "GestureComponentResource",
    'B5A3FDC1C5E0BC22': "MenuStyleTabHeader",
    'B5C19CFF86CAA013': "WeaponZoomResource",
    'B5CCE760BDEBFE14': "AIRobotMountedSkillContext",
    'B67F63C4BCFD3284': "FastTravelSettingsResource",
    'B68733466E202A08': "AISpringArmWeaponOperationResource",
    'B689571D88581935': "MusicPresetEventResource",
    'B691E5DE29F337CF': "SequenceNetworkUseLocationGroup",
    'B6974273844D9605': "RenderDataStreamingHintDataArea",
    'B6B4AEECCDF27F8C': "MeleeWeaponComponentResource",
    'B6E62803A5B65E3B': "PerkLevel",
    'B723206F6CC5EDB7': "AnimationTrackLinearFloat",
    'B7289D0B501DEF01': "Skeleton",
    'B7363AD8DC3B1FCF': "NodeConstantsResource",
    'B7832CC4E169AC5B': "LensFlareShimmerResource",
    'B79EBF73063229F7': "DisableConstraintsAction",
    'B7ACD6EBB1E7F6D9': "AwarenessMarkerComponentResource",
    'B7C48999DBC4930E': "MenuTabResource",
    'B7C8010A5E0E62E3': "FocusOutlineColorSettings",
    'B7EAB72CD19D95B6': "AISensorSetResource",
    'B7F0161639E813FC': "AIPerceptionResource",
    'B81E2B8FA86BCBCD': "ClimateWeatherState",
    'B855FA3260EFAA00': "LoadingHintConditionEnumFact",
    'B8574E68B0BB8A30': "DynamicSpawnEcotopeSetup",
    'B89A596B420BB2E2': "LocalizedTextResource",
    'B8A4E0ECEECC2413': "AIFaction",
    'B8AA4CF170323A31': "AIBehaviorGroupMember",
    'B8B093EFB8F86CF7': "HUDLogicElementFaderResource",
    'B8E1EEE047712137': "StaticMeshActorResource",
    'B8E67CB4A1B96187': "MorphemeAnimationManagerResource",
    'B8F3AE8DC4026BA6': "PathLocatorResource",
    'B90D20A5F6DCE9B1': "PropertyIsPerformingContextualAction",
    'B9309ED4189CD477': "PlayerCollisionQuestTrigger",
    'B93E26CC80A28C93': "HUDObjectInfoPositionerLogicResource",
    'B9646D07855017E2': "LensFlareRingResource",
    'B97F05B34966C174': "AIGroupRolesValidatorResource",
    'B98D1AA50745F997': "MenuTextureResource",
    'B9E5B8DD2E9D4B3E': "MeshExportRegion",
    'B9EE17CAF8F1A061': "EquipSlot",
    'B9F5EB82FA655AA2': "PlayWarpedAnimationComponentResource",
    'BA1EFBA69ABF91E0': "MenuProjectionResource",
    'BA3EA1201F9BD55B': "HUDCrosshairPart",
    'BA6D1D22741BEE33': "DestructibilityPartStateResource",
    'BA7B64D78B942F42': "DataSourceLanguageListResource",
    'BA858273D85DAB8C': "PerkCategory",
    'BAE164D488660B15': "FocusTargetType",
    'BAE237BA2DFEFF09': "AIRobotSkillContext",
    'BAFCC185DEB0307B': "EcotopeTile",
    'BB4DB2D5D96DD474': "ParTimeLevelInfo",
    'BB6E3877EA37A4B5': "SKDTreeResource",
    'BB8BE80F5DE1F95E': "CompressorConfigurationSet",
    'BBB0C544E78B731A': "MenuStyleSelectView",
    'BBB431F58ABB51F9': "PerkQuestReward",
    'BC2F556E77E451FB': "HorseJumpResource",
    'BC389A5FDFCA3941': "ActivateRobotStateAction",
    'BC8B315698D8C5E0': "ExternalAnimationConfiguration",
    'BCE003CEAA436F0B': "MenuMapResource",
    'BCE2F0227E8281C4': "ModifierStatDisplayEntry",
    'BCEE0F2CCAAAF251': "HUDLayerResource",
    'BD417998BDC88ABE': "SpawnpointSequenceEntityVariable",
    'BD7C8C7CCC247272': "ShakeResource",
    'BDC4122A059A4F3F': "PathHelperNodeResource",
    'BE234556245A3F05': "HeadGestureSettings",
    'BE44EA284E0F6EDA': "CustomQuestReward",
    'BE4C023677FD0BB7': "ChargedAmmoResource",
    'BE65FFD5C3314FF3': "BodyVariantComponentResource",
    'BE8C712186F920DC': "TrackingPathTrailMeshResource",
    'BEF889DA55D8AD45': "DoFApertureSettings",
    'BF92FA63800181D9': "RemoveInventoryItemAction",
    'BFAFFEA324751C2C': "MeleeWeaponAnimation",
    'C01C20BA784E3CC8': "AimAssistComponentResource",
    'C0331A764211BE8F': "LootDataSettings",
    'C06C5EBC4440BE84': "VignetteSettingsResource",
    'C0E5A55F6F870D2A': "HairResource",
    'C0EF9794784A1635': "AirMoverComponentPostureSettings",
    'C12FBD0227B56559': "HumanoidSpreadSettings",
    'C15E4479C4B55D49': "RobotMeleeWeaponComponentResource",
    'C18E71E3C977B0F3': "DataSourceRobotCatalogueResource",
    'C2048A2D9CC45D11': "AIPerchingComponentResource",
    'C22DFAA420824559': "DisassembleComponentResource",
    'C26D6704B3133F98': "VariableActorResource",
    'C27B8A3428CB957F': "HumanoidMountMode",
    'C28BF50FD263255B': "HealthBarComponentResource",
    'C294F29914483371': "DestructibilityResource",
    'C29CF1087461E4D5': "MenuStringBinding",
    'C2B2460A38E0669A': "LocalizedShaderVariableComponentResource",
    'C2C6ABEA06E2D5A6': "LoadingHintConditionNewGamePlus",
    'C2F08048253BB7A8': "AISkillResource",
    'C309AF0FE3789EAB': "AIDynamicObstacleRectangleResource",
    'C3185CCEF016C6B7': "EquipmentModificationSocketResource",
    'C31F0B0FB4C2E7D2': "AnimationSetMap",
    'C3271CFE9C8016CB': "BulletTimeComponentResource",
    'C32AB6C4047E82BF': "CameraMagnetTagResource",
    'C341ED9726DD3231': "AIBodyPartResource",
    'C3A49FE3D204CB4E': "TrackingPathQuestTrigger",
    'C3B0619E3AD4016E': "InventoryCollectionMerchantFreeTradingItem",
    'C3B3EF8C76D0408C': "InvalidatePhysicsContactsComponentResource",
    'C3BE52C878B3D211': "AIContextualSpeechEventMapPair",
    'C3CDBB757D43BBFD': "FireDurationsAnimationReference",
    'C3E3A18B4730665A': "EcotopeOverrideComponentResource",
    'C43CAA0AB638C8F1': "PropertyIsCurrentlyIdentifiedThreat",
    'C456713EF3CD2560': "DensityMaskMap",
    'C462D28DC7F295F4': "AIJumpsComponentResource",
    'C4AC9187199165B9': "MenuSelectViewItemResource",
    'C53D68CC5824DF3D': "HitReactionCooldownResource",
    'C557489E4E582462': "MenuActionOpenPage",
    'C56221C313345FD9': "LootItem",
    'C56B8810D9EB04FA': "ExecuteOnParentAction",
    'C57A0CBF68D84B35': "GrenadeEjectorResource",
    'C58E7D2B8B96F089': "AmbienceGlobalRenderVariableValues",
    'C612BB3CC01B11CF': "CancelDelayedActionAction",
    'C61CE7391586C96C': "PartialAnimationEventResource",
    'C62BD9D809F5F234': "LocationMarker",
    'C6355B9420CC3CA6': "UpgradeRecipe",
    'C65CD85E7DA9EA62': "PerkRewardGroup",
    'C668B09FA794005F': "CurveResource",
    'C68983CB857B9072': "CraftingRecipeIngredient",
    'C7039BCE138C2FF0': "PhysicsCharacterMoverResource",
    'C742362198048D12': "NodeGraphDestructibilityPartVariableOverride",
    'C7B71A280CAE807C': "MenuStyle",
    'C816EFD4B260F6CB': "RopeAnchorComponentResource",
    'C85D28D17C10854D': "MorphemeSoundEventRemapComponentResource",
    'C85E1B50F815F1F5': "MissionManagerResource",
    'C8ADA94C16BE3BB5': "IsDeadAction",
    'C8F5D82BE328DF85': "AimIKComponentResource",
    'C8FC6D2972C71664': "HitResponseBehaviourOutput",
    'C925950080D6D771': "RagdollComponentResource",
    'C9A3A2B5286FB158': "NPCScheduleEntryResource",
    'C9B76C33E60BB634': "SequenceNetworkCondition",
    'CA823B355AD4A5A5': "EchoScanComponentResource",
    'CAF3AFADDB751595': "UseLocationConditionHasBooleanFact",
    'CAFC54D8307C3422': "MenuDLCAnimateItemRarityResource",
    'CB23C23725A6DAFB': "SoldierResource",
    'CB2BAE469A2CD17F': "AIHapticSensor",
    'CB3C1A4EE1726435': "HitReactionSet",
    'CB7E843F033D9D87': "MeleeDamageSphere",
    'CB9F181672226166': "CameraPropertiesSetResource",
    'CBBF417E53B378B3': "AnnotationDetectionComponentResource",
    'CC0C78A16F42D0F5': "NodeGraphCraftingRecipeUUIDRefVariableOverride",
    'CC61BFE9C1B667B4': "WeaponUnlockResource",
    'CCADFDAF8A6BAE07': "NPCScheduleLocationAreaResource",
    'CCC7A7CA13D57149': "MasterBusSettings",
    'CCD28A0E452B067D': "AIHapticStimulusResource",
    'CCD92EC857811E85': "SceneComponentResource",
    'CD56E2D065711222': "SetPartsLocalOffsetAction",
    'CD5AE8D9F3B857B0': "HUDLogicTimelineResource",
    'CD5D67CD4B8C9CE9': "InventoryActionAbilityResource",
    'CD629F973CC7D11B': "HideAllPlayersEventResource",
    'CDD0BA540079B10F': "UseLocationGraphCondition",
    'CDF46515879786F2': "HUDDamageNumbersDisplaySettingsResource",
    'CE0FD0E13A82E6CB': "DamageOverTimeComponentResource",
    'CE797E4176DF557B': "Camera",
    'CE864CD45B0FFBCA': "LocationProximityQuestTrigger",
    'CEAE863D5B069E6B': "ContextualFactsComponentResource",
    'CEFD588149C95BA7': "PinDownComponentResource",
    'CF14BCDFC23C50FB': "DensityMultiply",
    'CF7A87BD63D37B20': "HairModelComponentResource",
    'CF941A479EC496E5': "SelectResourceByBoolFact",
    'CFBBDE5C4AADBDF9': "AIEyeColorHintResource",
    'CFE13B29159E5217': "ExertionEventComponentResource",
    'CFE45D61F1F70E32': "MenuListItemResource",
    'CFECF4DB69ACE1B4': "HandleParentAnimationEventComponentResource",
    'CFF7297B2B7EA598': "ParticleEmitter",
    'CFF8782B967C48AE': "UseLocationPriority",
    'D00F2C3F0A240623': "SpawnSetupGroup",
    'D02BDF61E2AF3993': "RemoveEntityAction",
    'D0531D7113C06228': "SmoothAimLocatorResource",
    'D081C4DA2ED4B34D': "HumanoidBodyVariant",
    'D0C5412D0FF33628': "MenuStyleLegend",
    'D127084F76FEBD04': "CheckpointAction",
    'D14F45FCD53415D3': "PropertyIsVictimOfContextualAction",
    'D1D3EEF6FFA4B814': "PropertyIsUsingPlayerTool",
    'D1EB849DCBAB32EB': "HUDLogicElementRotatorResource",
    'D1F01CB66FD7DDA4': "AITagsMappingResource",
    'D1F17BA1B57E72D0': "QuestTrackingPathObjective",
    'D1FB94E38F592B63': "AtmosphereHazeSettingsResource",
    'D202C0452F3B083E': "DataSourceRegionResource",
    'D263FFC4EECF4F6E': "ParticleSystemResourceDLC",
    'D273F8CDA89ADDA7': "CreateEffectComponentAction",
    'D29232A09AD17E48': "LinkedSoundParameterGroup",
    'D2D4DDBE39D8C383': "DataSourceModifyResource",
    'D314D92D22640ACD': "AttachToHelperMoverResource",
    'D3669F94AB042EA3': "AIMeleeWeaponComponentResource",
    'D3725F42A39347A4': "SpawnSetup",
    'D3DC2BBC36BE6CD7': "MenuDataSourceBinding",
    'D431C273D67B6175': "AnimationMotionDirectional",
    'D45D0D5AB1E9F962': "StreamingTileStateResource",
    'D468A2EBDDFB6383': "VirtualRTTIResource",
    'D47FB1B710B3DFE1': "DelayGravityComponentResource",
    'D4B186647AFBE775': "AmbienceSetupCollectionEntry",
    'D4C9AFBFC7F766FA': "DLCManagerGameResource",
    'D4EDB369FBF57FA2': "MenuTabboxResource",
    'D51BEDBA0F9FED6A': "SnowDetectionComponentResource",
    'D51F4E6C08FA20C7': "AIContextHintResource",
    'D543BBC7EFD91F3A': "LocationMarkerUpdaterSettings",
    'D5733810CC0E68F4': "PlacementResourceRegister",
    'D579F9D62E9052BE': "RelativeSoundMixResource",
    'D57C8477B0C72983': "AttackEventManagerResource",
    'D5ABD2CB812FE5D0': "RobotMeleeWeaponAnimationInfoDirectional",
    'D5B434468F879C93': "StaticConditionAction",
    'D5EBAFDECF57BF37': "PlayerCardUnlockResource",
    'D62DD8B908B8A8EB': "AISignalSettingsResource",
    'D678DE4170F453BB': "HitReactionSeriesResource",
    'D69B3617C3EE04E0': "WorldDataTextureMapEntry",
    'D6AAA1CB8071FED6': "SequenceNetworkPlayerChoiceNode",
    'D6C0DC37FA640C41': "MenuScrollingPanelResource",
    'D73A39298EB2166E': "MenuStyleSound",
    'D74AED10A484D11D': "DisplayStatDefinition",
    'D74F97AD20DC654E': "BooleanFactSelectEventResource2",
    'D777E4483774C2B4': "MonitoredAnimationResource",
    'D7830AF5E1FDF4E4': "SetCloakAiBodyVisualStimuliAction",
    'D791D036CA09375E': "AttachedAnnotationResource",
    'D7C86A01F71C50E5': "RingSegmentVolumetricAnnotation",
    'D82E27B5C82AFA7D': "DensityHeightMap",
    'D83841E650139F0B': "IntegerFact",
    'D83E678C6A3D40D4': "LightingRigComponentResource",
    'D84399F09FD8D4AB': "SnowInteractionPositionEventResource",
    'D8B0862FBC1F90CF': "AttackEventTag",
    'D90A29AFF238E628': "FactCollectionResource",
    'D91AF0EB764D42D9': "TrackObjectiveAction",
    'D92C8FAC3E6DD361': "HUDRepairLogicResource",
    'D92E5F17C4AF4D29': "AIMoverComponentResource",
    'D96F0AEB9CF838E2': "LightProbeExcludeZone",
    'D9A8E2BFE6C273C6': "AIHTNPlannerResource",
    'D9D879D9F4B896F7': "StageCameraActorResource",
    'D9F339901FCE886C': "MeleeDamageShapeResource",
    'DA0316FADB486EC4': "AtmosphereFogSettingsResource",
    'DA14070ADFD07160': "AnnotatedRouteNode",
    'DA184C9ED847DF32': "SendMessageEventResource",
    'DA467512FE4A670E': "HUDAIStateLogicResource",
    'DA57E35105228D3E': "StaticMeshInstance",
    'DA62F1BEC000E967': "DisableSensorsResource",
    'DA6B57CA4988B635': "StreamingTileResource",
    'DA853B181FD7FDA7': "BulletSystemResource",
    'DAAD429257E4D054': "MeleeDamageBox",
    'DAF62F4AC21E00E1': "SceneInstance",
    'DB0ACEEACE91FE11': "DamageTypeResourceSettingsGame",
    'DB33F013B2FAA1AC': "DamageModifierComponentResource",
    'DB3FF56FDBBBDAEA': "DamageSettings",
    'DB4B0A9858D71E9C': "StreamingProgramResource",
    'DB7813D4E82DB654': "VaultDetectionComponentResource",
    'DB794E6EA5E3FEED': "SmartObjectDesireComponentResource",
    'DBB442DCFD67907C': "FocusScannableObject",
    'DBB7D4FF9A3A8388': "LayeredIrradianceData",
    'DBCAE204F8C5890C': "CarryComponentResource",
    'DBE082E3CB54027A': "EntityDeathQuestTrigger",
    'DC09D125DE791A94': "LocationMarkerRepMapResource",
    'DC21F07F5B540564': "HasComponentAction",
    'DC22CE9FC510147B': "PhysicsContactEffectSystemSettings",
    'DC3D43D192F22E9B': "AIAtmosphereBoxResource",
    'DCAA4A55BF25E4B4': "GestureCollectionResource",
    'DCADA22787C15A81': "AISkillContext",
    'DCD6704C88270E6C': "PlayerNotificationResource",
    'DCDD805004D91620': "EjectEffectsLocationResource",
    'DCF2CFD94F18AC88': "ProjectileTrailComponentResource",
    'DD347A4AF0FFD597': "PhysicsWaterPoolFromHeightMap",
    'DD41976A5E7458D9': "StageActorResource",
    'DD584ACB407A2F03': "AIWeaponCarrierComponentResource",
    'DD77445804326DED': "AIContextResource",
    'DDA1D8F6E0D2E5D2': "AmbienceSetupCollection",
    'DDB821B42C71C00B': "AnimationEventEventResource",
    'DE0281867B4E1E6E': "SequenceNetworkCrateCarryingComponentResource",
    'DE056B31F1897B26': "AmbienceSetup",
    'DE2A70A5A9F4D496': "FacialAnimationProgramResource",
    'DE5972CD6243DCB2': "EventHandlerDefinition",
    'DE6ABC244F8C56F2': "MounterMoverResource",
    'DE6B2B1885D6F10A': "CombatDetectionComponentResource",
    'DF8789B5770E5AFA': "InventoryCapacityModificationComponentResource",
    'DF8ACD7B4A4BB540': "SunCascadeOccluderComponentResource",
    'DFD3C5DBBCB4E066': "AnimationActionEventResource",
    'DFE611C889BC101A': "NewGamePlusSettingsResourceGame",
    'E025D78F8F9FA01D': "IntegerFactQuestTrigger",
    'E07848EA01CCC566': "LensFlareSpikeBallResource",
    'E0B784D7596166A1': "DataSourceDataCubesResource",
    'E0BA167BD107650F': "FocusComponentResource",
    'E0E402D3DB254A19': "HUDCrosshairChargeLevelIndicatorSettings",
    'E0F0A6BE7ABCB026': "MenuLegendResource",
    'E0FBF965D454D93A': "HUDCrosshairLogicResource",
    'E137FE0D4D6C43F9': "XpQuestReward",
    'E13FBB1FB564F049': "InventoryCollectionEquippableWeaponItem",
    'E1763A96099EA3CA': "TelemetryComponentResource",
    'E193C5B74D86566F': "TrackingPathSettings",
    'E1FE86E6E5A6F2E8': "LootItemDescriptionResource",
    'E21AFE1CFF74847D': "SpawnSetupPlaceholder",
    'E21F303C4F35D7AE': "PartialAnimationSettings",
    'E21F991F815812A8': "QuestType",
    'E27729D271FFEC58': "SortedEvent",
    'E27D23D67B441C37': "OverrideGraphProgramResource",
    'E2A48CBEC31ADED9': "KillEventResource",
    'E2C0FCC7BBA2322B': "FontResource",
    'E2C6A429935BAFA1': "MenuListResource",
    'E2D58392C3A704E7': "DensityInvert",
    'E302A0110F9CB013': "WeaponModificationComponentResource",
    'E33AB08CAEF82747': "AIVisualStimulusComponentResource",
    'E34B33F0ED166B86': "SequenceNetworkComponentResource",
    'E37F3F8E428D167F': "MeleeWeaponModeResource",
    'E3A8E97DAEAD5932': "LabelEventResource",
    'E3BB874B04410B7C': "SentenceResource",
    'E4116723C65BD0BD': "MerchantTradingCollection",
    'E475C09892E8627A': "KillEntityAction",
    'E4BA7F673610E03D': "CloudRenderSettingsResource",
    'E59611F9B10492F1': "DiscoverableAreaStateManipulator",
    'E59A0166E7245EF7': "HitReactionResource",
    'E5B574D30E6F542C': "PickUpAnimationAction",
    'E5F7AABAAAAE7FA7': "TerrainHull",
    'E605F6EC1EE0979D': "PlacementLayer",
    'E61496B143A7948F': "DerivedStatResource",
    'E629582CFF963DEB': "MissionCoopResource",
    'E65426BAF8E14DBE': "PropertyIsSwimmingUnderWater",
    'E66A215C8C7F9EFA': "FogOfWarRevealArea",
    'E684591CC639E427': "LureEnemyComponentResource",
    'E7058BFB9ACA35FC': "WorldDrawableMap",
    'E74377AEF4C13D8E': "ExplorationSystemResource",
    'E744E9569299A212': "AIProximitySensor",
    'E75E323DBCDF3AC1': "PropertyIsParkouring",
    'E776709228218F23': "QuestItemTrackingObjective",
    'E7840B87C7C16086': "HorseControllerComponentResource",
    'E78862AE568E0484': "AIFollowTerrainWeaponOperationResource",
    'E7B27ED426D6D169': "SetGlobalLodBiasEventResource",
    'E7C20981C6EFE1A2': "MerchantStockInfo",
    'E7F19E0722DB661B': "NodeGraphFloatVariableOverride",
    'E8563B06959EB13D': "AIPatrolPath",
    'E875EEE67432004B': "HUDPopupMappingResource",
    'E8AA4894AD325A61': "IncreaseIntPropertyAction",
    'E8ED079C38041659': "RobotFuriousStateComponentResource",
    'E92D2611FF95B30A': "IndoorClimate",
    'E93CA5F4B788EB87': "PlayerRanksResource",
    'E940250BC190B1E3': "StatModificationSocketType",
    'E9547DE1A86AF381': "ProcessRobotActionAction",
    'E9C27FF65DD26346': "AmbienceSettingsTrack",
    'E9C898F780BD3294': "LocalizedAnimationResource",
    'EA30FF52A9C2BABA': "Terrain",
    'EA3B53DC1C853D97': "MapZonePortal",
    'EA406E0BCB9CE218': "AirNavigationComponentResource",
    'EA4CF450A5D46953': "AIRoad",
    'EA5D09687FC6FEA5': "AttachPhysicsInstanceComponentResource",
    'EA9D2BFF89EE671F': "PropertyIsInVegetation",
    'EAB30CD4A52A5524': "ProximityComponentResource",
    'EABA9EF793191484': "SeverityStatDisplayEntry",
    'EAC2C74E0F307C53': "RobotActionResource",
    'EAC7AB3A50E81E75': "PropertyIsMeleeing",
    'EAF9BDA916835480': "GraphSoundResource",
    'EB53519292C393EA': "NodeGraphHumanoidBodyVariantUUIDRefVariableOverride",
    'EB92E807A0EE39F8': "QuestObjective",
    'EBAD4D6D5EC3A856': "HUDToolSelectionLogicResource",
    'EBB19A86CD4129C5': "NodeGraphIntegerFactVariableOverride",
    'EBB3C4FD016A4977': "AnnotatedRouteDecoration",
    'EBC4083B0D246F0E': "SlowMotionEventResource",
    'EBC8659E189E9E2D': "WalkAndTalkPath",
    'EC610664544CEDA9': "OutOfBoundsQueryComponentResource",
    'EC69C16310765B1A': "GameStatisticsWeightedEntry",
    'EC6A0CF50CB8E73F': "PropertyContainerResource",
    'ECB95A128A34F66A': "NodeGraphEntityResourceVariableOverride",
    'ECF612AB47D30723': "TrackingPathTrailEntityResource",
    'ECFA6AAA28B3E78C': "SentenceGroupResource",
    'ED01E02542247261': "FacialEmotionEventResource",
    'ED194C216B5D9637': "ChangeModelPartAction",
    'ED35935185611AAB': "RopePullingComponentResource",
    'ED3629B5CED62855': "DamageTypeGroup",
    'ED86AD6C11707C21': "AIPropertyFactComponentResource",
    'EDB0FFF6B11650D8': "ScavengeHelperResource",
    'EDF1A9A3B932AB0D': "SunLightResource",
    'EE420640C8F7AFC2': "HUDAudiologPlayerLogicResource",
    'EE48361B489F504B': "WorldPositionProperty",
    'EE4F763C6A2E6635': "LocationMarkerComponentResource",
    'EEAB04695088558F': "CreateComponentAction",
    'EEC01F0450506FEF': "RemoveHUDElementAction",
    'EF4EF524BCFB1A68': "ItemDescriptionComponentResource",
    'EF5A2BE94A79CAAC': "SmartObjectDesireInfluence",
    'EF880A66FE42373D': "PushResponseComponentResource",
    'EF96219CD82A9044': "HUDSplashScreenLogicResource",
    'EFA976BF27CB049E': "AICombatSituationMessageHandlerResourceSet",
    'EFBAC3DF827565FB': "RoadNode",
    'EFCB8EA332C1DF13': "AINavMeshComponentResource",
    'F004E9F7765E65D2': "IsSpecifiedEntityAction",
    'F071DFC11C33E1F0': "SimpleStatModifierResource",
    'F091F703CAD2BB99': "MenuStyleClassBinding",
    'F10D3FFB13F214E3': "NodeGraphStringVariableOverride",
    'F12376B213EBAD39': "WeatherEventResource",
    'F13A87E1A407D2E5': "ChargedValueThresholdsFloat",
    'F13CE80EEE7D215F': "InteractiveMoverResource",
    'F14FC664E566FE96': "AmmoRecipe",
    'F1595FBD10A4412C': "ViewportSetupsResource",
    'F15A7D85843BD9E1': "BodyVariantHideHeadgearComponentResource",
    'F16E1C0C91D1F1FA': "HorseCallComponentResource",
    'F1BB5C8BF520840B': "HumanoidDismountMode",
    'F2CEFEAFFC410B33': "DiscoverableAreaDLC",
    'F2D7149F2418A825': "SSAOSettingsResource",
    'F32E55727166F8EC': "RenderingPrimitiveResource",
    'F34A76FAD0A1E0D7': "PrefetchList",
    'F35690769A072D9B': "HumanoidDeadStateResource",
    'F39342F364F5F518': "ConditionListenerComponentResource",
    'F3A071B36219C695': "DestructibilityPart",
    'F40AD19BBDDEE95D': "HUDCrosshairBulletIndicatorSettings",
    'F45513F8D63FE1C6': "DamageDealtModifierComponentResource",
    'F45C6BA16B2A4F32': "TerrainTileData",
    'F4648A55975DD022': "VaultSurfaceDetectionSettings",
    'F46708F2371E7559': "PlayAnimationObjectResource",
    'F491AFAC6135C432': "WorldDataTerrainNormalMapEntry",
    'F4A46B1FEF1CC639': "AIPathObjectComponentResource",
    'F4E500182CA939FD': "SoundComponentResource",
    'F515CDC6F436A49C': "CollectableManagerResource",
    'F545E881E4964E29': "GroundProjectileMoverResource",
    'F54D23F0352A1C5B': "PropertyIsZiplining",
    'F572848775C32E91': "ParticleEventResource",
    'F5802D764DE7DDD0': "HackableComponentResource",
    'F61AE7335F212ADD': "EntityPlaceHolder",
    'F6A0DBB66F3D7915': "HumanoidVaultTransition",
    'F6A8FF9585F5C786': "AIHTNPlannerDaemonGroupRolesDebugResource",
    'F6AE729438EA6AC6': "HUDXpLogicResource",
    'F6C5B733326C84E6': "ExternalAnimationComponentResource",
    'F6CC1A58AC52A361': "InventoryUnlockResource",
    'F6D9E91B9BFD135C': "AIThrowableOriginInfoMessageResource",
    'F6F66F882EB661E0': "MultiMeshResource",
    'F7183BAE030073F0': "AIHTNPlannerDaemonPropertiesResource",
    'F73C79417552568E': "LocalizedSimpleSoundResource",
    'F78DD4DE99807E98': "GameStatisticsEntryIntegerFact",
    'F791ABF590F3ABB2': "TypefaceStyle",
    'F7C89DEB5C717583': "LensFlareInstance",
    'F8086FDB67EBA1FE': "AnimationMotionCurve",
    'F8298F67758EC033': "Gradient",
    'F84C13B84F93927D': "MonitoredAnimationComponentResource",
    'F8AEF6D9E4ED2FB8': "EnableShadowsAction",
    'F8D1CE687A3F56F2': "AIRoadManagerResource",
    'F902BC82CA35F060': "IntProperty",
    'F919609437AE662E': "LinkedSoundParameterComponentResource",
    'F94DEF7AB4B4960E': "VegetationCoverComponentResource",
    'F950B26BF405BF82': "MapZoneSection",
    'F9B37223DC1FFEAD': "MenuStyleText",
    'F9EFC8EF30BEEAB1': "FacialPaintComponentResource",
    'FA22816E51EA382C': "ThrowableResource",
    'FA2E4E031321B009': "InventoryCollectionPackageComponentResource",
    'FA3035D9A2530BD4': "AIPlayerPerformanceFeedbackResource",
    'FA549AC01B52DFEE': "PhysicsCollisionGroupsResource",
    'FA5B754746919E7C': "MeleeWeaponAttackTypeResource",
    'FADE3EE0217861CB': "SmartObjectDesire",
    'FAEF08C0232ECBBE': "EntityProximityQuestTrigger",
    'FB3D89389FB48E2B': "LookAtTargetEventResource",
    'FB459817AAD447BC': "SelectResourceByInt",
    'FB7CCFF0DAB723BB': "CollectableSection",
    'FBAE529286D23DBC': "NodeGraphBooleanFactVariableOverride",
    'FBBF17A3E4EAFE2B': "HideMultiMeshPartEventResource",
    'FC13A4EEBF1A4F4E': "AmbienceEventResource",
    'FC1AEBAD624F1E82': "FirstPersonHitEffectsResource",
    'FC40DA9EBFE18F7A': "PropertyMounterIsMounted",
    'FC590E34DB289228': "DynamicHelperLocatorResource",
    'FC9B0F16BA5A03AF': "DensityMax",
    'FCC2FA6587A1077A': "HUDSavingLogicResource",
    'FCE5CEABA3B1BE47': "PhysicsRagdollConstraintResource",
    'FCEA5EBDC26D7B94': "ForceMinimumLodComponentResource",
    'FCFD1030CD03E6B4': "AIHTNPlannerDaemonAquaticResource",
    'FD0988271A43D86F': "MenuToastMessageResource",
    'FD236DAB1C71060A': "SmartObjectComponentResource",
    'FD3C7325D61FAC28': "FlameThrowerEjectorResource",
    'FD4FD9BEE9B59DA2': "AmmoResource",
    'FD546CFBBE875CCE': "AIDynamicObstacleCircleResource",
    'FD5BD37B80B2CBA7': "ExtraHealthComponentResource",
    'FD692BB2239F2DFA': "HumanoidAIWalkStateResource",
    'FD7FA385E6881250': "SoundPadSpeakerMasterParametersResource",
    'FD8188CDA83E1EE0': "SequenceNetworkResource",
    'FDAF69B56911427C': "AIBehaviorGroup",
    'FDF2F93F281CDB01': "HUDCrosshairPartChargeAnimationSettings",
    'FE0D7C5189A1825C': "GearMovementSoundComponentResource",
    'FE16277C0E5531C9': "HumanoidParkourDismountMode",
    'FE32C02F54FBF300': "HUDCrosshairPartTimelineAnimationSettings",
    'FE4DB6653C1A5508': "LocationMarkerDiscovererSettings",
    'FE8985A666DC9D97': "AIWeaponAttackResource",
    'FEE21D403DD2C82E': "PlayerConversationComponentResource",
    'FEEBCD0E7D6DC202': "WeaponsContainerComponentResource",
    'FEF5BD4CBCB567E4': "RenderDataStreamingHintData",
    'FEF940D4756CCD96': "SequenceNetworkSequenceNode",
    'FF13CEC40971C404': "Career",
    'FF3AC5D635D6849D': "MenuLegendLabelResource",
    'FF95E20E79B207A1': "ReverbSubmixResource",
    'FFAE269AC152D8A6': "PostureInfo",
    'FFFE04CA09A8DCE1': "UseLocationConditionIsPlayer"
}



from typing import BinaryIO
from pydecima.enums.DecimaVersion import DecimaVersion
import struct
from pydecima.resources.Resource import Resource
from pydecima.resources.structs.Ref import Ref
from pydecima._utils import parse_hashed_string

# TODO: Unfinished


class FacialAnimationComponentResource(Resource):
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        start_pos = stream.tell()
        Resource.__init__(self, stream, version)
        self.name = parse_hashed_string(stream)
        self.head_grp_multimesh = Ref(stream, self.version)
        self.skeleton = Ref(stream, self.version)
        self.bone_bounding_boxes = Ref(stream, self.version)
        self.neutral_anim = Ref(stream, self.version)
        self.unk_ints = struct.unpack('<II', stream.read(8))[0]
        self.face_rig_data = Ref(stream, self.version)
        self.expressions = Ref(stream, self.version)
        # TODO
        stream.seek(start_pos)
        self.data = stream.read(self.size + 12)

    def __str__(self):
        return '{}: {}'.format(self.type, self.name)



import struct
from typing import BinaryIO, List
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.enums.ETextureSetType import ETextureSetType
from pydecima.resources.Resource import Resource
from pydecima.resources.Texture import Texture
from pydecima.resources.structs.Ref import Ref
from pydecima._utils import parse_hashed_string


class TextureSet(Resource):
    class TextureDetails:
        class ChannelDetails:
            def __init__(self, stream: BinaryIO):
                channel_details = struct.unpack('<B', stream.read(1))[0]
                self.setType: ETextureSetType = ETextureSetType(channel_details & 0x0F)
                self.unk = channel_details >> 4

        def __init__(self, stream: BinaryIO, version):
            self.unk_int1 = struct.unpack('<I', stream.read(4))[0]
            self.unk_int2 = struct.unpack('<I', stream.read(4))[0]
            self.unk_byte = struct.unpack('<b', stream.read(1))
            self.channel_details: List[TextureSet.TextureDetails.ChannelDetails] = \
                [self.ChannelDetails(stream) for _ in range(4)]
            self.unk_int3 = struct.unpack('<I', stream.read(4))[0]
            self.texture: Ref[Texture] = Ref(stream, version)

    class SourceDetails:
        def __init__(self, stream: BinaryIO):
            set_type_int = struct.unpack('<I', stream.read(4))[0]
            self.set_type: ETextureSetType = ETextureSetType(set_type_int)
            self.source_filename = parse_hashed_string(stream)
            self.unk_byte1 = struct.unpack('<b', stream.read(1))
            self.unk_byte2 = struct.unpack('<b', stream.read(1))
            self.unk_int1 = struct.unpack('<I', stream.read(4))[0]
            self.unk_int2 = struct.unpack('<I', stream.read(4))[0]
            self.unk_int3 = struct.unpack('<I', stream.read(4))[0]
            self.width = struct.unpack('<I', stream.read(4))[0]
            self.height = struct.unpack('<I', stream.read(4))[0]
            self.unk_float1 = struct.unpack('<f', stream.read(4))[0]
            self.unk_float2 = struct.unpack('<f', stream.read(4))[0]
            self.unk_float3 = struct.unpack('<f', stream.read(4))[0]
            self.unk_float4 = struct.unpack('<f', stream.read(4))[0]

    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        Resource.__init__(self, stream, version)
        self.name = parse_hashed_string(stream)
        texture_count = struct.unpack('<I', stream.read(4))[0]
        self.textures = [self.TextureDetails(stream, version) for _ in range(texture_count)]
        self.unk_int1 = struct.unpack('<I', stream.read(4))[0]
        assert self.unk_int1 == 0
        source_count = struct.unpack('<I', stream.read(4))[0]
        self.sources = [self.SourceDetails(stream) for _ in range(source_count)]

    def __str__(self):
        return '{}: {}'.format(self.type, self.name)



import struct
from typing import BinaryIO, List, Optional
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources.Resource import Resource
from pydecima.resources.structs.Ref import Ref
from pydecima._utils import parse_hashed_string


class LocalizedSimpleSoundResource(Resource):
    class SoundInfo:
        def __init__(self, stream: BinaryIO):
            self.size_1 = struct.unpack('<I', stream.read(4))[0]
            self.sample_count = struct.unpack('<I', stream.read(4))[0]
            self.unk_3 = struct.unpack('<I', stream.read(4))[0]
            assert (self.unk_3 == 0)
            self.start = struct.unpack('<I', stream.read(4))[0]
            self.unk_5 = struct.unpack('<I', stream.read(4))[0]
            assert (self.unk_5 == 0)
            self.size_2 = struct.unpack('<I', stream.read(4))[0]
            self.unk_7 = struct.unpack('<I', stream.read(4))[0]
            assert (self.unk_7 == 0)
            assert (self.size_1 == self.size_2), "size 1 and 2 don't match"

    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        Resource.__init__(self, stream, version)
        self.name = parse_hashed_string(stream)
        self.unk_floats_1: List[float] = [struct.unpack('<f', stream.read(4))[0] for _ in range(17)]
        self.unk_bytes_2 = stream.read(17)
        self.unk_floats_3: List[float] = [struct.unpack('<f', stream.read(4))[0] for _ in range(9)]
        self.unk_bytes_4 = stream.read(3)
        self.state_relative_mix = Ref(stream, self.version)
        self.sound_preset = Ref(stream, self.version)
        filename_len = struct.unpack('<I', stream.read(4))[0]
        self.sound_filename = stream.read(filename_len).decode('UTF8')
        self.language_flags = struct.unpack('<H', stream.read(2))[0]
        assert (self.language_flags <= 0xFFF), "unrecognized language flag"
        self.unk_byte_5 = stream.read(1)
        self.audio_type = struct.unpack('<b', stream.read(1))[0]
        # 9: at9
        # b: mp3
        # d: at9, TODO: Figure out what's different from 9
        # f: aac, ps4-only
        assert (self.audio_type in [0x09, 0x0b, 0x0d, 0x0f]), f"unrecognized sound type {self.audio_type}"
        self.unk_bytes_6 = stream.read(4)
        self.sample_rate = struct.unpack('<I', stream.read(4))[0]
        self.bits_per_sample = struct.unpack('<H', stream.read(2))[0]
        self.bit_rate = struct.unpack('<I', stream.read(4))[0]
        self.unk_short_8 = struct.unpack('<H', stream.read(2))[0]
        self.unk_short_9 = struct.unpack('<H', stream.read(2))[0]
        self.sound_info: List[Optional[LocalizedSimpleSoundResource.SoundInfo]] = list()
        for i in range(12):
            if self.language_flags & (1 << i) != 0:
                self.sound_info.append(LocalizedSimpleSoundResource.SoundInfo(stream))
            else:
                self.sound_info.append(None)

    def __str__(self):
        return '{}: {}'.format(self.type, self.name)



from .DecimaVersion import DecimaVersion
from .EAudioLanguages import EAudioLanguages
from .EPixelFormat import EPixelFormat
from .ESentenceGroupType import ESentenceGroupType
from .ETextLanguages import ETextLanguages
from .ETextureSetType import ETextureSetType
from .EWaveDataEncoding import EWaveDataEncoding
from .EWaveDataEncodingQuality import EWaveDataEncodingQuality



from enum import IntEnum


class EAudioLanguages(IntEnum):
    English = 0,
    French = 1,
    Spanish = 2,
    German = 3,
    Italian = 4,
    Portugese = 5,
    Russian = 6,
    Polish = 7,
    Japanese = 8,
    LatAmSp = 9,  # Latin-American Spanish
    LatAmPor = 10,  # Brazilian Portuguese
    Arabic = 11



import struct
from typing import BinaryIO, List
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources.HumanoidBodyVariant import HumanoidBodyVariant
from pydecima.resources.Resource import Resource
from pydecima.resources.structs.Ref import Ref
from pydecima._utils import parse_hashed_string


class HumanoidBodyVariantGroup(Resource):
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        Resource.__init__(self, stream, version)
        self.name = parse_hashed_string(stream)
        body_variants_count = struct.unpack('<I', stream.read(4))[0]
        self.body_variants: List[Ref[HumanoidBodyVariant]] = \
            [Ref(stream, self.version) for _ in range(body_variants_count)]

    def __str__(self):
        return '{}: {}'.format(self.type, self.name)



from io import BytesIO
import struct
from typing import BinaryIO
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources.Resource import Resource
from pydecima.resources.structs.ImageStruct import ImageStruct
from pydecima._utils import parse_hashed_string


class UITexture(Resource):
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        Resource.__init__(self, stream, version)
        self.name_1 = parse_hashed_string(stream)
        self.name_2 = parse_hashed_string(stream)
        assert self.name_1 == self.name_2, f"UITexture names don't match: {self.name_1}, {self.name_2}"
        self.initial_width = struct.unpack('<I', stream.read(4))[0]
        self.initial_height = struct.unpack('<I', stream.read(4))[0]
        self.sizes = struct.unpack('<II', stream.read(8))
        self.image_data = ImageStruct(BytesIO(stream.read(self.sizes[0])), version) if self.sizes[0] > 0 else None
        self.image_data_2 = ImageStruct(BytesIO(stream.read(self.sizes[1])), version) if self.sizes[1] > 0 else None

    def __str__(self):
        streamed = hasattr(self.image_data_2, "size_of_stream") and self.image_data_2.size_of_stream > 0
        return f'{self.type}: {self.name_2}, {self.image_data_2.width}x{self.image_data_2.height}, ' + \
               f'{self.image_data_2.image_format.name}, {"streamed " if streamed else ""}' + \
               f'@{hex(self.image_data_2.stream_start) if streamed else "internal"}'



import struct
from typing import BinaryIO, List
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources.LocalizedTextResource import LocalizedTextResource
from pydecima.resources.Resource import Resource
from pydecima.resources.structs.Ref import Ref
from pydecima._utils import parse_hashed_string


class InventoryItemComponentResource(Resource):
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        Resource.__init__(self, stream, version)
        self.name = parse_hashed_string(stream)
        self.item_name: Ref[LocalizedTextResource] = Ref(stream, self.version)
        self.item_description: Ref[LocalizedTextResource] = Ref(stream, self.version)
        self.item_price_info = Ref(stream, self.version)
        self.unk = struct.unpack('<I', stream.read(4))[0]
        self.item_icon = Ref(stream, self.version)
        self.item_icon_2 = Ref(stream, self.version)
        self.broken_ref = Ref(stream, self.version)
        self.unk_ref = Ref(stream, self.version)
        self.unk_ref2 = Ref(stream, self.version)
        self.unk_ref3 = Ref(stream, self.version)
        ref_count = struct.unpack('<I', stream.read(4))[0]
        self.ref_list: List[Ref] = [Ref(stream, self.version) for _ in range(ref_count)]
        self.unk_short = struct.unpack('<H', stream.read(2))[0]
        ref_count_2 = struct.unpack('<I', stream.read(4))[0]
        self.ref_list_2: List[Ref] = [Ref(stream, self.version) for _ in range(ref_count_2)]
        stream.read(5)  # TODO
        self.soundbank = Ref(stream, self.version)
        self.unk_ref3 = Ref(stream, self.version)
        stream.read(2)  # TODO



import struct
from typing import BinaryIO, List
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources.Resource import Resource
from pydecima.resources.structs.Ref import Ref
from pydecima._utils import parse_hashed_string


class InventoryEntityResource(Resource):
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        start_pos = stream.tell()
        Resource.__init__(self, stream, version)
        stream.seek(start_pos + 12)
        self.unk = struct.unpack('<h', stream.read(2))[0]
        self.uuid = stream.read(16)
        self.name = parse_hashed_string(stream)
        stream.read(7)  # TODO
        Ref(stream, self.version)
        stream.read(16)
        self.multiAction = Ref(stream, self.version)
        self.unk3 = Ref(stream, self.version)
        ref_count = struct.unpack('<I', stream.read(4))[0]
        self.ref_list: List[Ref] = [Ref(stream, self.version) for _ in range(ref_count)]

        stream.seek(start_pos)
        self.data = stream.read(self.size + 12)



from enum import IntEnum


class EWaveDataEncodingQuality(IntEnum):
    Uncompressed__PCM_ = 0x0,
    Lossy_Lowest = 0x1,
    Lossy_Low = 0x2,
    Lossy_Medium = 0x3,
    Lossy_High = 0x4,
    Lossy_Highest = 0x5



import struct
from typing import BinaryIO, List
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources.LootItem import LootItem
from pydecima.resources.Resource import Resource
from pydecima.resources.structs.Ref import Ref
from pydecima._utils import parse_hashed_string


class LootData(Resource):
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        Resource.__init__(self, stream, version)
        self.name = parse_hashed_string(stream)
        self.probability: float = struct.unpack('<f', stream.read(4))[0]
        self.unkRef = Ref(stream, self.version)  # Never seems to be valid(?)
        ref_count = struct.unpack('<I', stream.read(4))[0]
        self.loot_item: List[Ref[LootItem]] = [Ref(stream, self.version) for _ in range(ref_count)]
        self.quantity: int = struct.unpack('<I', stream.read(4))[0]
        self.unk3: int = struct.unpack('<b', stream.read(1))[0]

    def __str__(self):
        return '{}: {}'.format(self.type, self.name)



import struct
from typing import BinaryIO
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources.Resource import Resource
from pydecima.resources.structs.Ref import Ref
from pydecima._utils import parse_hashed_string


class LootItem(Resource):
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        start_pos = stream.tell()
        Resource.__init__(self, stream, version)
        self.name = parse_hashed_string(stream)
        self.unk: float = struct.unpack('<f', stream.read(4))[0]
        self.unk2 = Ref(stream, self.version)
        self.inventoryEntity = Ref(stream, self.version)

        stream.seek(start_pos)
        self.data = stream.read(self.size + 12)

    def __str__(self):
        return '{}: {}'.format(self.type, self.name)



import struct
from typing import BinaryIO
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources.LocalizedSimpleSoundResource import LocalizedSimpleSoundResource
from pydecima.resources.LocalizedTextResource import LocalizedTextResource
from pydecima.resources.VoiceResource import VoiceResource
from pydecima.resources.Resource import Resource
from pydecima.resources.structs.Ref import Ref
from pydecima._utils import parse_hashed_string


# TODO: Unfinished
class SentenceResource(Resource):
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        Resource.__init__(self, stream, version)
        self.name = parse_hashed_string(stream)
        self.unk_int = struct.unpack('<I', stream.read(4))[0]
        self.unk_byte_1 = struct.unpack('<b', stream.read(1))[0]
        self.unk_byte_2 = struct.unpack('<b', stream.read(1))[0]
        self.sound: Ref[LocalizedSimpleSoundResource] = Ref(stream, self.version)
        self.animation: Ref = Ref(stream, self.version)
        self.text: Ref[LocalizedTextResource] = Ref(stream, self.version)
        self.voice: Ref[VoiceResource] = Ref(stream, self.version)

    def __str__(self):
        return '{}: {}'.format(self.type, self.name)



import binascii
import struct
from typing import BinaryIO
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.type_maps import get_type_map


class Resource:
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        self.type_hash = struct.unpack('<Q', stream.read(8))[0]
        self.version = version
        little_endian_type = '{0:X}'.format(self.type_hash)
        type_map = get_type_map(version)
        if little_endian_type in type_map:
            self.type = type_map[little_endian_type]
        else:
            self.type = 'Unknown Type'
        self.size = struct.unpack('<I', stream.read(4))[0]
        self.uuid = stream.read(16)

    def __str__(self):
        return '{}: {}'.format(self.type, binascii.hexlify(self.uuid).decode('ASCII'))

    def __repr__(self):
        return self.__str__()



import struct
from typing import BinaryIO, List
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources.LocalizedTextResource import LocalizedTextResource
from pydecima.resources.Resource import Resource
from pydecima.resources.structs.Ref import Ref
from pydecima._utils import parse_hashed_string


class FocusScannedInfo(Resource):
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        Resource.__init__(self, stream, version)
        self.name = parse_hashed_string(stream)
        self.title: Ref[LocalizedTextResource] = Ref(stream, self.version)
        self.description_alternate: Ref[LocalizedTextResource] = Ref(stream, self.version)
        self.description: Ref[LocalizedTextResource] = Ref(stream, self.version)
        self.target_type = Ref(stream, self.version)
        category_count = struct.unpack('<I', stream.read(4))[0]
        self.categories: List[Ref] = [Ref(stream, self.version) for _ in range(category_count)]
        self.scannable_body = Ref(stream, self.version)
        self.outlineSettings = Ref(stream, self.version)
        property_count = struct.unpack('<I', stream.read(4))[0]
        self.properties: List[Ref] = [Ref(stream, self.version) for _ in range(property_count)]
        self.graph_condition = Ref(stream, self.version)

    def __str__(self):
        return '{}: {}'.format(self.type, self.name)



from typing import BinaryIO
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources.Resource import Resource


class SkeletonAnimationResource(Resource):
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        Resource.__init__(self, stream, version)
        self.data = stream.read(self.size - 16)



from typing import BinaryIO
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources.LocalizedTextResource import LocalizedTextResource
from pydecima.resources.Resource import Resource
from pydecima.resources.structs.Ref import Ref
from pydecima._utils import parse_hashed_string

# TODO: Unfinished


class CharacterDescriptionComponentResource(Resource):
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        Resource.__init__(self, stream, version)
        self.name = parse_hashed_string(stream)
        self.character_name: Ref[LocalizedTextResource] = Ref(stream, self.version)
        self.unk_1 = Ref(stream, self.version)
        assert self.unk_1.type == 0
        self.character_type_class = Ref(stream, self.version)
        self.unk_2 = Ref(stream, self.version)
        assert self.unk_2.type == 0

    def __str__(self):
        return '{}: {}'.format(self.type, self.name)



from .AmmoResource import AmmoResource
from .CharacterDescriptionComponentResource import CharacterDescriptionComponentResource
from .CollisionTrigger import CollisionTrigger
from .CreditsColumn import CreditsColumn
from .CreditsRow import CreditsRow
from .DamageAreaResource import DamageAreaResource
from .DataSourceCreditsResource import DataSourceCreditsResource
from .EntityProjectileAmmoResource import EntityProjectileAmmoResource
from .EntityResource import EntityResource
from .ExplosionResource import ExplosionResource
from .FacialAnimationComponentResource import FacialAnimationComponentResource
from .FactCollisionTrigger import FactCollisionTrigger
from .FocusScannedInfo import FocusScannedInfo
from .FocusTargetComponentResource import FocusTargetComponentResource
from .HumanoidBodyVariant import HumanoidBodyVariant
from .HumanoidBodyVariantGroup import HumanoidBodyVariantGroup
from .InventoryActionAbilityResource import InventoryActionAbilityResource
from .InventoryAmmoEjectorResource import InventoryAmmoEjectorResource
from .InventoryEntityResource import InventoryEntityResource
from .InventoryItemComponentResource import InventoryItemComponentResource
from .InventoryLootPackageComponentResource import InventoryLootPackageComponentResource
from .LocalizedAnimationResource import LocalizedAnimationResource
from .LocalizedSimpleSoundResource import LocalizedSimpleSoundResource
from .LocalizedTextResource import LocalizedTextResource
from .LootData import LootData
from .LootItem import LootItem
from .LootSlot import LootSlot
from .MusicResource import MusicResource
from .ObjectCollection import ObjectCollection
from .OutOfBoundsNavMeshArea import OutOfBoundsNavMeshArea
from .PhysicsCollisionResource import PhysicsCollisionResource
from .PrefetchList import PrefetchList
from .Resource import Resource
from .SentenceGroupResource import SentenceGroupResource
from .SentenceResource import SentenceResource
from .SkeletonAnimationResource import SkeletonAnimationResource
from .SpawnSetup import SpawnSetup
from .SpawnSetupGroup import SpawnSetupGroup
from .Texture import Texture
from .TextureSet import TextureSet
from .ThrowableResource import ThrowableResource
from .UITexture import UITexture
from .UnknownResource import UnknownResource
from .VoiceComponentResource import VoiceComponentResource
from .VoiceResource import VoiceResource
from .VoiceSignalsResource import VoiceSignalsResource
from .WaveResource import WaveResource



import io
from typing import BinaryIO, List
from pydecima.enums.DecimaVersion import DecimaVersion
import struct
from pydecima.resources.Resource import Resource
from pydecima.resources.structs.Ref import Ref
from pydecima._utils import parse_hashed_string


class MusicResource(Resource):
    class FourCCTableEntry:
        def __init__(self, stream: BinaryIO):
            self.name = stream.read(4).decode('ascii')
            self.offset = struct.unpack("<I", stream.read(4))[0]
            self.size = struct.unpack("<I", stream.read(4))[0]

    class MEDASectionEntry:
        def __init__(self, stream: BinaryIO):
            self.offset = struct.unpack("<Q", stream.read(8))[0]
            self.size = struct.unpack("<Q", stream.read(8))[0]
            self.unk = [struct.unpack("<I", stream.read(4))[0] for _ in range(8)]

    class MEDASection:
        def __init__(self, stream: BinaryIO):
            self.magic = stream.read(4).decode('ascii')
            assert self.magic == 'PICD', "Magic != PICD"
            offsets_size = struct.unpack("<I", stream.read(4))[0]
            stream.read(8)  # padding?
            self.offsets: List[MusicResource.MEDASectionEntry] =\
                [MusicResource.MEDASectionEntry(stream) for _ in range(offsets_size)]

    class SectionStruct:
        def __init__(self, stream: BinaryIO):
            start_pos = stream.tell()
            fourcc_table_start_pos = start_pos + 12
            self.fourcc_table = [MusicResource.FourCCTableEntry(stream)]
            assert self.fourcc_table[0].name == "ECHO", "First entry wasn't ECHO"

            while stream.tell() - fourcc_table_start_pos < self.fourcc_table[0].size:
                self.fourcc_table.append(MusicResource.FourCCTableEntry(stream))
            self.sections = {}
            for section in self.fourcc_table:
                stream.seek(section.offset)
                if section.name == "MEDA":
                    self.sections[section.name] = MusicResource.MEDASection(stream)
                elif section.name == "STRL":
                    self.sections[section.name] = stream.read(section.size).decode('ascii').split('\00')[:-1]
                else:
                    self.sections[section.name] = stream.read(section.size)

    class CacheStruct:
        def __init__(self, stream: BinaryIO):
            cache_string_length = struct.unpack("<I", stream.read(4))[0]
            self.cache_string = stream.read(cache_string_length).decode('ascii')
            self.unk1 = struct.unpack("<I", stream.read(4))[0]
            self.unk2 = struct.unpack("<I", stream.read(4))[0]
            self.file_size = struct.unpack("<I", stream.read(4))[0]
            self.unk3 = struct.unpack("<I", stream.read(4))[0]

    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        Resource.__init__(self, stream, version)
        self.name = parse_hashed_string(stream)
        unk1_count = struct.unpack("<I", stream.read(4))[0]
        self.unk1 = [struct.unpack("<I", stream.read(4))[0] for _ in range(unk1_count)]
        self.unk2 = struct.unpack("<I", stream.read(4))[0]
        self.unk3 = struct.unpack("<B", stream.read(1))[0]
        self.unk4 = struct.unpack("<i", stream.read(4))[0]
        submix_count = struct.unpack("<I", stream.read(4))[0]
        self.submixes = []
        for _ in range(submix_count):
            submix_name = parse_hashed_string(stream)
            submix_ref = Ref(stream, self.version)
            self.submixes.append((submix_name, submix_ref))
        chunk_name_count = struct.unpack("<I", stream.read(4))[0]
        self.chunk_names = [parse_hashed_string(stream) for _ in range(chunk_name_count)]
        section_struct_size = struct.unpack("<I", stream.read(4))[0]
        self.section_struct = MusicResource.SectionStruct(io.BytesIO(stream.read(section_struct_size)))
        self.cache_structs = [MusicResource.CacheStruct(stream) for _ in range(chunk_name_count)]

    def __str__(self):
        return '{}: {}'.format(self.type, self.name)

    def __repr__(self):
        return self.__str__()



import struct
from typing import BinaryIO
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources.Resource import Resource
from pydecima.resources.SpawnSetup import SpawnSetup
from pydecima.resources.structs.Ref import Ref
from pydecima._utils import parse_hashed_string


class SpawnSetupGroup(Resource):
    class UnkStruct:
        def __init__(self, stream: BinaryIO, version: DecimaVersion):
            self.unk_float = struct.unpack('<f', stream.read(4))[0]
            self.unk_ref: [Ref[SpawnSetup], Ref[SpawnSetupGroup]] = Ref(stream, version)

    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        Resource.__init__(self, stream, version)
        self.name = parse_hashed_string(stream)
        self.unk_boolean_fact = Ref(stream, self.version)
        self.unk2 = Ref(stream, self.version)
        assert self.unk2.type == 0
        unk_struct_count = struct.unpack('<I', stream.read(4))[0]
        self.unk_structs = [SpawnSetupGroup.UnkStruct(stream, self.version) for _ in range(unk_struct_count)]

    def __str__(self):
        return '{}: {}'.format(self.type, self.name)



from typing import BinaryIO
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources.Resource import Resource


class UnknownResource(Resource):
    def __init__(self, stream: BinaryIO, version: DecimaVersion):
        start_pos = stream.tell()
        Resource.__init__(self, stream, version)
        if self.uuid[:2] == b'\x00\x00':
            print('{} likely has starting short'.format(self.type))
            stream.seek(start_pos + 14)
            self.uuid = stream.read(16)
        stream.seek(start_pos)
        self.data = stream.read(self.size + 12)



import io
import os
import struct
import binascii
from typing import Dict
from pydecima.enums.DecimaVersion import DecimaVersion
from pydecima.resources import Resource, UnknownResource
from pydecima.type_maps import get_type_map
import pydecima.resources
import inspect

defined_resource_types = [member[0] for member in inspect.getmembers(pydecima.resources)]
game_root: str = ""
decima_version: DecimaVersion = DecimaVersion.HZDPC
use_buffering: bool = False


def set_globals(*, _game_root=None, _game_root_file=None, _decima_version=None, _use_buffering=None):
    global game_root
    global decima_version
    global use_buffering

    if type(_game_root) == str and type(_game_root_file) == str:
        raise ValueError("_game_root and _game_root_file cannot both be specified")
    elif type(_game_root) == str:
        assert os.path.isdir(_game_root), "_game_root is not a valid directory"
        game_root = _game_root
    elif type(_game_root_file) == str:
        assert os.path.isfile(_game_root_file), "_game_root_file is not a valid file"
        root_file_contents = open(_game_root_file, 'r').read().strip('" \t\r\n')
        assert os.path.isdir(root_file_contents), "_game_root_file does not contain a path to a valid directory"
        game_root = root_file_contents

    if type(_decima_version) == DecimaVersion:
        decima_version = _decima_version
    elif type(_decima_version) == str:
        version = DecimaVersion(_decima_version.upper())
        decima_version = version

    if type(_use_buffering) == bool:
        use_buffering = _use_buffering


def read_objects(in_file_name: str, out_dict: Dict[bytes, Resource]):
    with open(in_file_name, 'rb') as in_file:
        try:
            return read_objects_from_stream(io.BytesIO(in_file.read()), out_dict)
        except Exception as e:
            raise Exception(f'Error in {in_file_name}: {e}')


def read_objects_from_stream(in_file: io.BytesIO, out_dict: Dict[bytes, Resource]):
    type_map = get_type_map(decima_version)

    while True:
        start_pos = in_file.tell()
        if not in_file.read(1):
            break
        in_file.seek(start_pos)
        type_hash, size = struct.unpack('<QI', in_file.read(12))
        in_file.seek(start_pos)
        if use_buffering:
            stream = io.BytesIO(in_file.read(12 + size))
        else:
            stream = in_file
        # check type map to see if we have a dedicated constructor
        little_endian_type = '{0:X}'.format(type_hash)
        type_name: str = "Unknown"
        if little_endian_type in type_map:
            type_name = type_map[little_endian_type]

        parse_start_pos = stream.tell()

        if type_name in defined_resource_types:
            try:
                specific_res = eval(f'pydecima.resources.{type_name}(stream, decima_version)')
                out_dict[specific_res.uuid] = specific_res
                parse_end_pos = stream.tell()
                read_count = (parse_end_pos - parse_start_pos)
                if size + 12 != read_count:
                    raise Exception("{} {} didn't match size, expected {}, read {}"
                          .format(specific_res.type, binascii.hexlify(specific_res.uuid).decode('ASCII'),
                                  size + 12, read_count))
            except Exception as e:
                stream.seek(parse_start_pos)
                unknown_res = UnknownResource(stream, decima_version)
                raise Exception("{} {} failed to parse, error: {}"
                                .format(type_name, binascii.hexlify(unknown_res.uuid).decode('ASCII'), e))
        else:
            unknown_res = UnknownResource(stream, decima_version)
            out_dict[unknown_res.uuid] = unknown_res
